"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactHooks = require("@polkadot/react-hooks");

var _translate = require("./translate");

var _util = require("./util");

var _AddressMini = _interopRequireDefault(require("./AddressMini"));

var _Badge = _interopRequireDefault(require("./Badge"));

var _Dropdown = _interopRequireDefault(require("./Dropdown"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _Input = _interopRequireDefault(require("./Input"));

var _InputAddress = _interopRequireDefault(require("./InputAddress"));

var _Modal = _interopRequireDefault(require("./Modal"));

var _TxButton = _interopRequireDefault(require("./TxButton"));

// Copyright 2017-2020 @polkadot/react-query authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const JUDGEMENT_ENUM = [{
  value: 0,
  text: 'Unknown'
}, {
  value: 1,
  text: 'Fee paid'
}, {
  value: 2,
  text: 'Reasonable'
}, {
  value: 3,
  text: 'Known good'
}, {
  value: 4,
  text: 'Out of date'
}, {
  value: 5,
  text: 'Low quality'
}];
const DISPLAY_KEYS = ['display', 'legal', 'email', 'web', 'twitter', 'riot'];
const nameCache = new Map();

function defaultOrAddr(defaultName = '', _address, _accountIndex) {
  const accountId = _address.toString();

  const accountIndex = (_accountIndex || '').toString();

  const [isAddressExtracted,, extracted] = (0, _util.getAddressName)(accountId, null, defaultName);
  const [isAddressCached, nameCached] = nameCache.get(accountId) || [false, [null, null]];

  if (extracted && isAddressCached && !isAddressExtracted) {// skip, default return
  } else if (nameCached[0]) {
    return [nameCached, false, isAddressCached];
  } else if (isAddressExtracted && accountIndex) {
    nameCache.set(accountId, [true, [accountIndex, null]]);
    return [[accountIndex, null], false, true];
  }

  return [[extracted, null], !isAddressExtracted, isAddressExtracted];
}

function AccountName({
  children,
  className,
  defaultName,
  label,
  onClick,
  override,
  style,
  toggle,
  value,
  withShort
}) {
  var _api$query$identity;

  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    api
  } = (0, _reactHooks.useApi)();
  const {
    allAccounts
  } = (0, _reactHooks.useAccounts)();
  const [isJudgementOpen, toggleJudgement] = (0, _reactHooks.useToggle)();
  const registrars = (0, _reactHooks.useCall)((_api$query$identity = api.query.identity) === null || _api$query$identity === void 0 ? void 0 : _api$query$identity.registrars, []);
  const info = (0, _reactHooks.useCall)(api.derive.accounts.info, [value]);
  const [accountId, setAccountId] = (0, _react.useState)(null);
  const [isRegistrar, setIsRegistrar] = (0, _react.useState)(false);
  const [judgementAccountId, setJudgementAccountId] = (0, _react.useState)(null);
  const [judgementEnum, setJudgementEnum] = (0, _react.useState)(2); // Reasonable

  const [registrarIndex, setRegistrarIndex] = (0, _react.useState)(-1);
  const address = (0, _react.useMemo)(() => (value || '').toString(), [value]);

  const _extractName = (accountId, accountIndex) => {
    const [[displayFirst, displaySecond], isLocal, isAddress] = defaultOrAddr(defaultName, accountId || address, withShort ? null : accountIndex);
    return _react.default.createElement("div", {
      className: "via-identity"
    }, _react.default.createElement("span", {
      className: "name ".concat(isLocal ? 'isLocal' : isAddress ? 'isAddress' : '')
    }, displaySecond ? _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("span", {
      className: "top"
    }, displayFirst), _react.default.createElement("span", {
      className: "sub"
    }, "/", displaySecond)) : displayFirst));
  };

  const [name, setName] = (0, _react.useState)(() => _extractName()); // determine if we have a registrar or not - registrars are allowed to approve

  (0, _react.useEffect)(() => {
    if (allAccounts && registrars) {
      setIsRegistrar(registrars.map(registrar => registrar.isSome ? registrar.unwrap().account.toString() : null).some(regId => !!regId && allAccounts.includes(regId)));
    }
  }, [allAccounts, registrars]); // find the id of our registrar in the list

  (0, _react.useEffect)(() => {
    if (registrars && judgementAccountId) {
      setRegistrarIndex(registrars.map(registrar => registrar.isSome ? registrar.unwrap().account.toString() : null).indexOf(judgementAccountId));
    } else {
      setRegistrarIndex(-1);
    }
  }, [judgementAccountId, registrars]); // set the actual nickname, localname, accountIndex, accountId

  (0, _react.useEffect)(() => {
    var _api$query$identity2;

    const {
      accountId,
      accountIndex,
      identity,
      nickname
    } = info || {};

    if (accountId) {
      setAccountId(accountId.toString());
    }

    if ((_api$query$identity2 = api.query.identity) === null || _api$query$identity2 === void 0 ? void 0 : _api$query$identity2.identityOf) {
      if (identity === null || identity === void 0 ? void 0 : identity.display) {
        const judgements = identity.judgements.filter(([, judgement]) => !judgement.isFeePaid);
        const isGood = judgements.some(([, judgement]) => judgement.isKnownGood || judgement.isReasonable);
        const isBad = judgements.some(([, judgement]) => judgement.isErroneous || judgement.isLowQuality);
        const waitCount = identity.judgements.length - judgements.length;

        const hover = _react.default.createElement("div", null, _react.default.createElement("div", null, judgements.length ? judgements.length === 1 ? t('1 judgement') : t('{{count}} judgements', {
          replace: {
            count: judgements.length
          }
        }) : t('no judgements'), judgements.length ? ': ' : '', judgements.map(([, judgement]) => judgement.toString()).join(', '), waitCount ? t(' ({{count}} waiting)', {
          replace: {
            count: waitCount
          }
        }) : ''), _react.default.createElement("table", null, _react.default.createElement("tbody", null, identity.parent && _react.default.createElement("tr", null, _react.default.createElement("td", null, t('parent')), _react.default.createElement("td", null, _react.default.createElement(_AddressMini.default, {
          value: identity.parent
        }))), DISPLAY_KEYS.filter(key => !!identity[key]).map(key => _react.default.createElement("tr", {
          key: key
        }, _react.default.createElement("td", null, t(key)), _react.default.createElement("td", null, identity[key]))))));

        const displayName = isGood ? identity.display : identity.display.replace(/[^\x20-\x7E]/g, '');
        const displayParent = identity.displayParent ? isGood ? identity.displayParent : identity.displayParent.replace(/[^\x20-\x7E]/g, '') : undefined;

        const name = _react.default.createElement("div", {
          className: "via-identity"
        }, _react.default.createElement(_Badge.default, {
          hover: hover,
          info: _react.default.createElement(_Icon.default, {
            name: identity.parent ? 'caret square up outline' : isGood ? 'check' : 'minus'
          }),
          isInline: true,
          isSmall: true,
          isTooltip: true,
          onClick: isRegistrar ? toggleJudgement : undefined,
          type: isGood ? 'green' : isBad ? 'brown' : 'gray'
        }), displayParent ? _react.default.createElement("span", {
          className: "name ".concat(isGood && 'isGood')
        }, _react.default.createElement("span", {
          className: "top"
        }, displayParent), _react.default.createElement("span", {
          className: "sub"
        }, "/", displayName)) : _react.default.createElement("span", {
          className: "name ".concat(isGood && 'isGood')
        }, displayName));

        nameCache.set(address, [false, displayParent ? [displayParent, displayName] : [displayName, null]]);
        setName(() => name);
      } else {
        setName(() => _extractName(accountId, accountIndex));
      }
    } else if (nickname) {
      nameCache.set(address, [false, [nickname, null]]);
      setName(nickname);
    } else {
      setName(defaultOrAddr(defaultName, accountId || address, withShort ? null : accountIndex));
    }
  }, [info, toggle]);
  return _react.default.createElement(_react.default.Fragment, null, isJudgementOpen && _react.default.createElement(_Modal.default, {
    header: t('Provide judgement'),
    size: "small"
  }, _react.default.createElement(_Modal.default.Content, null, _react.default.createElement(_InputAddress.default, {
    label: t('registrar account'),
    onChange: setJudgementAccountId
  }), _react.default.createElement(_Input.default, {
    isDisabled: true,
    label: t('registrar index'),
    value: registrarIndex === -1 ? t('invalid/unknown registrar account') : registrarIndex
  }), _react.default.createElement(_Dropdown.default, {
    label: t('judgement'),
    onChange: setJudgementEnum,
    options: JUDGEMENT_ENUM,
    value: judgementEnum
  })), _react.default.createElement(_Modal.default.Actions, {
    onCancel: toggleJudgement
  }, _react.default.createElement(_TxButton.default, {
    accountId: judgementAccountId,
    icon: "check",
    isDisabled: registrarIndex === -1,
    label: t('Judge'),
    onStart: toggleJudgement,
    params: [registrarIndex, accountId, judgementEnum],
    tx: "identity.provideJudgement"
  }))), _react.default.createElement("div", {
    className: "ui--AccountName ".concat(className),
    onClick: override ? undefined : onClick,
    style: style
  }, label || '', override || name, children));
}

var _default = (0, _styledComponents.default)(AccountName).withConfig({
  displayName: "AccountName",
  componentId: "sc-1660clv-0"
})([".via-identity{display:inline-block;overflow:hidden;text-overflow:ellipsis;vertical-align:bottom;width:100%;.name{font-weight:normal !important;filter:grayscale(100%);opacity:0.6;text-transform:uppercase;&.isAddress{font-family:monospace;text-transform:none;}&.isGood,&.isLocal{opacity:1;}.sub{font-size:0.75rem;opacity:0.75;}}div.name{display:inline-block;}> *{line-height:1em;vertical-align:middle;}.ui--Badge{margin-top:-2px;}}"]);

exports.default = _default;