"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _bn = _interopRequireDefault(require("bn.js"));

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _util = require("@polkadot/util");

var _reactComponents = require("@polkadot/react-components");

var _hoc = require("@polkadot/react-api/hoc");

var _reactHooks = require("@polkadot/react-hooks");

var _reactQuery = require("@polkadot/react-query");

var _CryptoType = _interopRequireDefault(require("./CryptoType"));

var _Label = _interopRequireDefault(require("./Label"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const PERBILL = new _bn.default(1000000000);
const DEFAULT_BALANCES = {
  available: true,
  bonded: true,
  locked: true,
  redeemable: true,
  reserved: true,
  total: true,
  unlocking: true,
  vested: true
};
const DEFAULT_EXTENDED = {
  crypto: true,
  nonce: true
};
const DEFAULT_PREFS = {
  unstakeThreshold: true,
  validatorPayment: true
}; // skip balances retrieval of none of this matches

function skipBalancesIf({
  withBalance = true,
  withExtended = false
}) {
  if (withBalance === true || withExtended === true) {
    return false;
  } else if ((0, _util.isObject)(withBalance)) {
    // these all pull from the all balances
    if (withBalance.available || withBalance.locked || withBalance.reserved || withBalance.total || withBalance.vested) {
      return false;
    }
  } else if ((0, _util.isObject)(withExtended)) {
    if (withExtended.nonce) {
      return false;
    }
  }

  return true;
}

function skipStakingIf({
  stakingInfo,
  withBalance = true,
  withRewardDestination = false,
  withValidatorPrefs = false
}) {
  if (stakingInfo) {
    return true;
  } else if (withBalance === true || withValidatorPrefs || withRewardDestination) {
    return false;
  } else if ((0, _util.isObject)(withBalance)) {
    if (withBalance.unlocking || withBalance.redeemable) {
      return false;
    } else if (withBalance.bonded) {
      return Array.isArray(withBalance.bonded);
    }
  }

  return true;
} // calculates the bonded, first being the own, the second being nominated


function calcBonded(stakingInfo, bonded) {
  let other = [];
  let own = new _bn.default(0);

  if (Array.isArray(bonded)) {
    other = bonded.filter((_, index) => index !== 0).filter(value => value.gtn(0));
    own = bonded[0];
  } else if (stakingInfo && stakingInfo.stakingLedger && stakingInfo.accountId.eq(stakingInfo.stashId)) {
    own = stakingInfo.stakingLedger.active.unwrap();
  }

  return [own, other];
}

function renderExtended({
  balancesAll,
  address,
  withExtended
}, t) {
  const extendedDisplay = withExtended === true ? DEFAULT_EXTENDED : withExtended || undefined;

  if (!extendedDisplay) {
    return null;
  }

  return _react.default.createElement("div", {
    className: "column"
  }, balancesAll && extendedDisplay.nonce && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('transactions')
  }), _react.default.createElement("div", {
    className: "result"
  }, (0, _util.formatNumber)(balancesAll.accountNonce))), extendedDisplay.crypto && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('type')
  }), _react.default.createElement(_CryptoType.default, {
    accountId: address,
    className: "result"
  })));
}

function renderUnlocking({
  stakingInfo
}, t) {
  if (!stakingInfo || !stakingInfo.unlocking || !stakingInfo.unlocking.length) {
    return null;
  }

  const total = stakingInfo.unlocking.reduce((total, {
    value
  }) => total.add(value), new _bn.default(0));

  if (total.eqn(0)) {
    return null;
  }

  return _react.default.createElement("div", null, _react.default.createElement(_reactQuery.FormatBalance, {
    value: total
  }), _react.default.createElement(_reactComponents.Icon, {
    name: "info circle",
    "data-tip": true,
    "data-for": "unlocking-trigger"
  }), _react.default.createElement(_reactComponents.Tooltip, {
    text: stakingInfo.unlocking.map(({
      remainingBlocks,
      value
    }, index) => _react.default.createElement("div", {
      key: index
    }, t('{{value}}, {{remaining}} blocks left', {
      replace: {
        remaining: (0, _util.formatNumber)(remainingBlocks),
        value: (0, _util.formatBalance)(value, {
          forceUnit: '-'
        })
      }
    }))),
    trigger: "unlocking-trigger"
  }));
}

function renderValidatorPrefs({
  stakingInfo,
  withValidatorPrefs = false
}, t) {
  const validatorPrefsDisplay = withValidatorPrefs === true ? DEFAULT_PREFS : withValidatorPrefs;

  if (!validatorPrefsDisplay || !stakingInfo || !stakingInfo.validatorPrefs) {
    return null;
  }

  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", null), validatorPrefsDisplay.unstakeThreshold && stakingInfo.validatorPrefs.unstakeThreshold && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('unstake threshold')
  }), _react.default.createElement("div", {
    className: "result"
  }, stakingInfo.validatorPrefs.unstakeThreshold.toString())), validatorPrefsDisplay.validatorPayment && (stakingInfo.validatorPrefs.commission || stakingInfo.validatorPrefs.validatorPayment) && (stakingInfo.validatorPrefs.validatorPayment ? _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('commission')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: stakingInfo.validatorPrefs.validatorPayment
  })) : _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('commission')
  }), _react.default.createElement("span", null, (stakingInfo.validatorPrefs.commission.unwrap().muln(10000).div(PERBILL).toNumber() / 100).toFixed(2), "%"))));
}

function renderBalances(props, allAccounts, t) {
  var _stakingInfo$controll, _balancesAll$lockedBa, _balancesAll$reserved, _stakingInfo$redeemab;

  const {
    balancesAll,
    stakingInfo,
    withBalance = true,
    withBalanceToggle = false
  } = props;
  const balanceDisplay = withBalance === true ? DEFAULT_BALANCES : withBalance || false;

  if (!balanceDisplay) {
    return null;
  }

  const [ownBonded, otherBonded] = calcBonded(stakingInfo, balanceDisplay.bonded);
  const controllerId = stakingInfo === null || stakingInfo === void 0 ? void 0 : (_stakingInfo$controll = stakingInfo.controllerId) === null || _stakingInfo$controll === void 0 ? void 0 : _stakingInfo$controll.toString();

  const allItems = _react.default.createElement(_react.default.Fragment, null, balancesAll && balanceDisplay.total && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('total')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: balancesAll.votingBalance
  })), balancesAll && balanceDisplay.available && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('transferrable')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: balancesAll.availableBalance
  })), balanceDisplay.vested && (balancesAll === null || balancesAll === void 0 ? void 0 : balancesAll.isVesting) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('vested')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: balancesAll.vestedBalance
  })), balanceDisplay.locked && (balancesAll === null || balancesAll === void 0 ? void 0 : (_balancesAll$lockedBa = balancesAll.lockedBalance) === null || _balancesAll$lockedBa === void 0 ? void 0 : _balancesAll$lockedBa.gtn(0)) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('locked')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: balancesAll.lockedBalance
  })), balanceDisplay.reserved && (balancesAll === null || balancesAll === void 0 ? void 0 : (_balancesAll$reserved = balancesAll.reservedBalance) === null || _balancesAll$reserved === void 0 ? void 0 : _balancesAll$reserved.gtn(0)) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('reserved')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: balancesAll.reservedBalance
  })), balanceDisplay.bonded && (ownBonded.gtn(0) || otherBonded.length !== 0) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('bonded')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: ownBonded
  }, otherBonded.length !== 0 && _react.default.createElement(_react.default.Fragment, null, "\xA0(+", otherBonded.map((bonded, index) => _react.default.createElement(_reactQuery.FormatBalance, {
    key: index,
    value: bonded
  })), ")"))), balanceDisplay.redeemable && (stakingInfo === null || stakingInfo === void 0 ? void 0 : (_stakingInfo$redeemab = stakingInfo.redeemable) === null || _stakingInfo$redeemab === void 0 ? void 0 : _stakingInfo$redeemab.gtn(0)) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('redeemable')
  }), _react.default.createElement(_reactQuery.FormatBalance, {
    className: "result",
    value: stakingInfo.redeemable
  }, controllerId && allAccounts.includes(controllerId) && _react.default.createElement(_reactComponents.TxButton, {
    accountId: controllerId,
    className: "icon-button",
    icon: "lock",
    size: "small",
    isPrimary: true,
    key: "unlock",
    params: [],
    tooltip: t('Redeem these funds'),
    tx: "staking.withdrawUnbonded"
  }))), balanceDisplay.unlocking && (stakingInfo === null || stakingInfo === void 0 ? void 0 : stakingInfo.unlocking) && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('unbonding')
  }), _react.default.createElement("div", {
    className: "result"
  }, renderUnlocking(props, t))));

  if (withBalanceToggle) {
    return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("label", null, t('balances')), _react.default.createElement("details", null, _react.default.createElement("summary", null, _react.default.createElement("div", {
      className: "body"
    }, _react.default.createElement(_reactQuery.FormatBalance, {
      value: balancesAll === null || balancesAll === void 0 ? void 0 : balancesAll.votingBalance
    }))), _react.default.createElement("div", {
      className: "body column"
    }, allItems)));
  }

  return _react.default.createElement(_react.default.Fragment, null, allItems);
}

function AddressInfo(props) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    allAccounts
  } = (0, _reactHooks.useAccounts)();
  const {
    className,
    children,
    extraInfo,
    stakingInfo,
    withBalanceToggle,
    withHexSessionId,
    withRewardDestination
  } = props;
  return _react.default.createElement("div", {
    className: "ui--AddressInfo ".concat(className, " ").concat(withBalanceToggle ? 'ui--AddressInfo-expander' : '')
  }, _react.default.createElement("div", {
    className: "column ".concat(withBalanceToggle ? 'column--expander' : '')
  }, renderBalances(props, allAccounts, t), withHexSessionId && withHexSessionId[0] && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('session keys')
  }), _react.default.createElement("div", {
    className: "result"
  }, withHexSessionId[0])), withHexSessionId && withHexSessionId[0] !== withHexSessionId[1] && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('session next')
  }), _react.default.createElement("div", {
    className: "result"
  }, withHexSessionId[1])), renderValidatorPrefs(props, t), extraInfo && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", null), extraInfo.map(([label, value], index) => _react.default.createElement(_react.default.Fragment, {
    key: "label:".concat(index)
  }, _react.default.createElement(_Label.default, {
    label: label
  }), _react.default.createElement("div", {
    className: "result"
  }, value)))), withRewardDestination && stakingInfo && stakingInfo.rewardDestination && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Label.default, {
    label: t('rewards')
  }), _react.default.createElement("div", {
    className: "result"
  }, stakingInfo.rewardDestination.toString().toLowerCase()))), renderExtended(props, t), children && _react.default.createElement("div", {
    className: "column"
  }, children));
}

var _default = (0, _hoc.withMulti)((0, _styledComponents.default)(AddressInfo).withConfig({
  displayName: "AddressInfo",
  componentId: "s8skq6-0"
})(["align-items:flex-start;display:flex;flex:1;white-space:nowrap;&:not(.ui--AddressInfo-expander){justify-content:center;}.column{justify-content:start;&.column--expander{text-align:left;width:15rem;details[open] summary{.body{opacity:0;}}details summary{width:100%;.body{display:inline-block;text-align:right;min-width:12rem;}}}&:not(.column--expander){flex:1;display:grid;opacity:1;label{grid-column:1;padding-right:0.5rem;text-align:right;vertical-align:middle;.help.circle.icon{display:none;}}.result{grid-column:2;.icon{margin-left:.3em;margin-right:0;padding-right:0 !important;}button.ui.icon.primary.button.icon-button{background:white !important;}}}}"]), (0, _hoc.withCalls)(['derive.balances.all', {
  paramName: 'address',
  propName: 'balancesAll',
  skipIf: skipBalancesIf
}], ['derive.staking.account', {
  paramName: 'address',
  propName: 'stakingInfo',
  skipIf: skipStakingIf
}]));

exports.default = _default;