"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AddressRow = exports.DEFAULT_ADDR = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _hoc = require("@polkadot/react-api/hoc");

var _reactIdenticon = _interopRequireDefault(require("@polkadot/react-identicon"));

var _uiKeyring = _interopRequireDefault(require("@polkadot/ui-keyring"));

var _AddressInfo = _interopRequireDefault(require("./AddressInfo"));

var _util = require("./util");

var _IdentityIcon = _interopRequireWildcard(require("./IdentityIcon"));

var _Row = _interopRequireWildcard(require("./Row"));

var _translate = _interopRequireDefault(require("./translate"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const DEFAULT_ADDR = '5'.padEnd(16, 'x');
exports.DEFAULT_ADDR = DEFAULT_ADDR;
const ICON_SIZE = 48;
const ICON_SIZE_SMALL = 32;
const EMPTY_INFO = {
  identity: {
    judgements: []
  }
};

class AddressRow extends _Row.default {
  constructor(props) {
    super(props);
    this.state = void 0;

    this.saveName = () => {
      const {
        address,
        name
      } = this.state;
      const trimmedName = name.trim();
      const meta = {
        name: trimmedName,
        whenEdited: Date.now()
      }; // Save only if the name was changed or if it's no empty.

      if (trimmedName && address) {
        try {
          const currentKeyring = _uiKeyring.default.getPair(address);

          currentKeyring && _uiKeyring.default.saveAccountMeta(currentKeyring, meta);
        } catch (error) {
          _uiKeyring.default.saveAddress(address, meta);
        }
      }

      this.setState({
        isEditingName: false
      });
    };

    this.saveTags = () => {
      const {
        address,
        tags
      } = this.state;
      const meta = {
        tags,
        whenEdited: Date.now()
      };

      if (address) {
        try {
          const currentKeyring = _uiKeyring.default.getPair(address);

          currentKeyring && _uiKeyring.default.saveAccountMeta(currentKeyring, meta);
        } catch (error) {
          _uiKeyring.default.saveAddress(address, meta);
        }

        this.setState({
          isEditingTags: false
        });
      }
    };

    this.state = this.createState();
  }

  static getDerivedStateFromProps({
    accounts_info = EMPTY_INFO,
    defaultName,
    isEditable,
    noDefaultNameOpacity,
    type,
    value
  }, prevState) {
    const accountId = accounts_info.accountId || value;
    const address = accountId ? accountId.toString() : DEFAULT_ADDR;
    const [, isDefault, nameInner] = accounts_info.nickname ? [true, false, accounts_info.nickname.toUpperCase()] : (0, _util.getAddressName)(address, type, defaultName || '<unknown>');
    const name = isDefault && !noDefaultNameOpacity && !isEditable ? _react.default.createElement("div", {
      className: "ui--Row-placeholder"
    }, nameInner) : nameInner;
    const tags = (0, _util.getAddressTags)(address, type);
    const state = {
      tags
    };
    let hasChanged = false;

    if (address !== prevState.address) {
      state.address = address;
      hasChanged = true;
    }

    if (!prevState.isEditingName && name !== prevState.name) {
      state.name = name;
      hasChanged = true;
    }

    return hasChanged ? state : null;
  }

  render() {
    const {
      accounts_info = EMPTY_INFO,
      className,
      isContract,
      isDisabled,
      isInline,
      label,
      overlay,
      style
    } = this.props;
    const {
      accountId,
      accountIndex
    } = accounts_info;
    const isValid = this.props.isValid || accountId || accountIndex;
    return _react.default.createElement("div", {
      className: (0, _util.classes)('ui--Row', isDisabled && 'isDisabled', !isValid && 'isInvalid', isInline && 'isInline', className),
      style: style
    }, _react.default.createElement("div", {
      className: "ui--Row-base"
    }, this.renderIcon(), _react.default.createElement("div", {
      className: "ui--Row-details"
    }, label && _react.default.createElement("label", {
      className: "account-label"
    }, label), this.renderAddressAndName(), this.renderAccountIndex(), !isContract && this.renderBalances(), this.renderTags()), this.renderButtons()), this.renderChildren(), overlay);
  }

  createState() {
    const {
      accounts_info = EMPTY_INFO,
      defaultName,
      type,
      value
    } = this.props;
    const accountId = accounts_info.accountId || value;
    const address = accountId ? accountId.toString() : DEFAULT_ADDR;
    const [,, name] = (0, _util.getAddressName)(address, type, defaultName || '<unknown>');
    const tags = (0, _util.getAddressTags)(address, type);
    return _objectSpread({}, this.state, {
      address,
      name,
      tags
    });
  }

  renderAddressAndName() {
    const {
      withAddressOrName = false
    } = this.props;

    if (withAddressOrName) {
      return this.renderName(true);
    } else {
      return _react.default.createElement(_react.default.Fragment, null, this.renderName(), this.renderAddress());
    }
  }

  renderAddress() {
    const {
      accounts_info = EMPTY_INFO,
      withIndexOrAddress = true
    } = this.props;
    const {
      address
    } = this.state;
    const {
      accountIndex
    } = accounts_info;

    if (accountIndex && withIndexOrAddress) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Row-accountId"
    }, (0, _util.toShortAddress)(address));
  }

  renderAccountIndex() {
    const {
      accounts_info = EMPTY_INFO,
      withIndex = true,
      withIndexOrAddress = true,
      withSmallIcon
    } = this.props;
    const {
      accountIndex
    } = accounts_info;

    if (withSmallIcon || !accountIndex || !(withIndex || withIndexOrAddress)) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Row-accountIndex"
    }, accountIndex.toString());
  }

  renderBalances() {
    const {
      accounts_info = EMPTY_INFO,
      extraInfo,
      stakingInfo,
      withBalance,
      withValidatorPrefs
    } = this.props;
    const {
      accountId
    } = accounts_info;

    if (!(withBalance || withValidatorPrefs) || !accountId) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Row-balances"
    }, _react.default.createElement(_AddressInfo.default, {
      address: accountId,
      extraInfo: extraInfo,
      stakingInfo: stakingInfo,
      withBalance: withBalance,
      withValidatorPrefs: withValidatorPrefs
    }));
  }

  renderIcon() {
    const {
      accounts_info = EMPTY_INFO,
      iconInfo,
      systemName,
      withIcon = true,
      withSmallIcon = false
    } = this.props;
    const {
      address
    } = this.state;
    const {
      accountId
    } = accounts_info;

    if (!withIcon) {
      return null;
    } // Since we do queries to storage in the wrapped example, we don't want
    // to follow that route if we don't have a valid address.


    const Component = accountId ? _IdentityIcon.default : _reactIdenticon.default;
    const theme = (0, _IdentityIcon.getIdentityTheme)(systemName);
    return _react.default.createElement("div", {
      className: "ui--Row-icon"
    }, _react.default.createElement(Component, {
      size: withSmallIcon ? ICON_SIZE_SMALL : ICON_SIZE,
      theme: theme,
      value: address
    }), iconInfo && _react.default.createElement("div", {
      className: "ui--Row-icon-info"
    }, iconInfo));
  }

}

exports.AddressRow = AddressRow;

var _default = (0, _hoc.withMulti)((0, _styledComponents.default)(AddressRow).withConfig({
  displayName: "AddressRow",
  componentId: "tqdufl-0"
})(["", " .ui--Row-placeholder{opacity:0.5;}.ui--Row-accountId,.ui--Row-accountIndex{font-family:monospace;}"], _Row.styles), _translate.default, (0, _hoc.withCalls)(['derive.accounts.info', {
  paramName: 'value'
}]));

exports.default = _default;