"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ChartHorizBar;

var _react = _interopRequireWildcard(require("react"));

var _chart = _interopRequireDefault(require("chart.js"));

var _reactChartjs = require("react-chartjs-2");

var _util = require("@polkadot/util");

/* eslint-disable @typescript-eslint/no-unused-vars */
// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const alphaColor = hexColor => _chart.default.helpers.color(hexColor).alpha(0.65).rgbString();

function calculateOptions(aspectRatio, values, jsonValues, max, showLabels) {
  const chartData = values.reduce((data, {
    colors: [normalColor = '#00f', hoverColor],
    label,
    value
  }) => {
    const dataset = data.datasets[0];
    dataset.backgroundColor.push(alphaColor(normalColor));
    dataset.hoverBackgroundColor.push(alphaColor(hoverColor || normalColor));
    dataset.data.push((0, _util.isNumber)(value) ? value : (0, _util.bnToBn)(value).toNumber());
    data.labels.push(label);
    return data;
  }, {
    labels: [],
    datasets: [{
      data: [],
      backgroundColor: [],
      hoverBackgroundColor: []
    }]
  });
  return {
    chartData,
    chartOptions: {
      // width/height by default this is "1", i.e. a square box
      aspectRatio,
      // no need for the legend, expect the labels contain everything
      legend: {
        display: false
      },
      scales: {
        xAxes: [{
          ticks: showLabels ? {
            beginAtZero: true,
            max
          } : {
            display: false
          }
        }]
      },
      tooltips: {
        callbacks: {
          label: (item, _) => values[item.index].tooltip || values[item.index].label
        }
      }
    },
    jsonValues
  };
}

function ChartHorizBar({
  aspectRatio = 8,
  className,
  max = 100,
  showLabels = false,
  style,
  values
}) {
  const [{
    chartData,
    chartOptions,
    jsonValues
  }, setState] = (0, _react.useState)({});
  (0, _react.useEffect)(() => {
    const newJsonValues = JSON.stringify(values);

    if (newJsonValues !== jsonValues) {
      setState(calculateOptions(aspectRatio, values, newJsonValues, max, showLabels));
    }
  }, [values]);

  if (!chartData) {
    return null;
  } // HACK on width/height to get the aspectRatio to work


  return _react.default.createElement("div", {
    className: className,
    style: style
  }, _react.default.createElement(_reactChartjs.HorizontalBar, {
    data: chartData,
    height: null,
    options: chartOptions,
    width: null
  }));
}