"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = LineChart;

var _bn = _interopRequireDefault(require("bn.js"));

var _react = _interopRequireWildcard(require("react"));

var _chart = _interopRequireDefault(require("chart.js"));

var _reactChartjs = require("react-chartjs-2");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const COLORS = ['#ff8c00', '#008c8c', '#8c008c'];

const alphaColor = hexColor => _chart.default.helpers.color(hexColor).alpha(0.65).rgbString();

function calculateOptions(colors = [], legends, labels, values, jsonValues) {
  const chartData = values.reduce((config, values, index) => {
    const color = colors[index] || alphaColor(COLORS[index]);
    const data = values.map(value => _bn.default.isBN(value) ? value.toNumber() : value);
    config.datasets.push({
      data,
      fill: false,
      label: legends[index],
      backgroundColor: color,
      borderColor: color,
      hoverBackgroundColor: color
    });
    return config;
  }, {
    labels,
    datasets: []
  });
  return {
    chartData,
    chartOptions: {
      // no need for the legend, expect the labels contain everything
      legend: {
        display: false
      },
      scales: {
        xAxes: [{
          ticks: {
            beginAtZero: true
          }
        }]
      }
    },
    jsonValues
  };
}

function LineChart({
  className,
  colors,
  labels,
  legends,
  style,
  values
}) {
  const [{
    chartData,
    chartOptions,
    jsonValues
  }, setState] = (0, _react.useState)({});
  (0, _react.useEffect)(() => {
    const newJsonValues = JSON.stringify(values);

    if (newJsonValues !== jsonValues) {
      setState(calculateOptions(colors, legends, labels, values, newJsonValues));
    }
  }, [labels, legends, values]);

  if (!chartData) {
    return null;
  }

  return _react.default.createElement("div", {
    className: className,
    style: style
  }, _react.default.createElement(_reactChartjs.Line, {
    data: chartData,
    options: chartOptions
  }));
}