"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _types = require("@polkadot/types");

var _reactApi = require("@polkadot/react-api");

var _hoc = require("@polkadot/react-api/hoc");

var _util = require("@polkadot/react-components/util");

var _store = _interopRequireDefault(require("@polkadot/app-contracts/store"));

var _CopyButton = _interopRequireDefault(require("./CopyButton"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _Messages = _interopRequireDefault(require("./Messages"));

var _Row = _interopRequireWildcard(require("./Row"));

var _translate = _interopRequireDefault(require("./translate"));

/* eslint-disable @typescript-eslint/camelcase */
// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const DEFAULT_HASH = '0x';
const DEFAULT_NAME = '<unknown>';

const CodeIcon = _styledComponents.default.div.withConfig({
  displayName: "CodeRow__CodeIcon",
  componentId: "sc-187tvvu-0"
})(["&{margin-right:1em;background:#eee;color:#666;width:4rem;height:5rem;padding:0.5rem;display:flex;justify-content:flex-end;align-items:flex-end;}"]);

const DEFAULT_ADDR = '5'.padEnd(16, 'x');

class CodeRow extends _Row.default {
  constructor(props) {
    super(props);
    this.state = void 0;

    this.saveName = async () => {
      const {
        codeHash,
        name
      } = this.state;
      const trimmedName = name.trim(); // Save only if the name was changed or if it's no empty.

      if (trimmedName && codeHash) {
        await _store.default.saveCode((0, _types.createType)(_reactApi.registry, 'Hash', codeHash), {
          name
        });
        this.setState({
          isEditingName: false
        });
      }
    };

    this.saveTags = async () => {
      const {
        codeHash,
        tags
      } = this.state;

      if (codeHash) {
        await _store.default.saveCode((0, _types.createType)(_reactApi.registry, 'Hash', codeHash), {
          tags
        });
        this.setState({
          isEditingTags: false
        });
      }
    };

    this.state = this.createState();
  }

  static getDerivedStateFromProps({
    code: {
      json
    },
    accounts_info
  }, prevState) {
    const codeHash = json.codeHash || DEFAULT_HASH;
    const name = json.name || DEFAULT_NAME;
    const tags = json.tags || [];
    const {
      accountId
    } = accounts_info || {};
    const address = accountId ? accountId.toString() : DEFAULT_ADDR;
    const state = {
      tags
    };
    let hasChanged = false;

    if (codeHash !== prevState.codeHash) {
      state.codeHash = codeHash;
      hasChanged = true;
    }

    if (!prevState.isEditingName && name !== prevState.name) {
      state.name = name;
      hasChanged = true;
    }

    if (address !== prevState.address) {
      state.address = address;
      hasChanged = true;
    }

    return hasChanged ? state : null;
  }

  render() {
    const {
      className,
      isInline,
      style
    } = this.props;
    return _react.default.createElement("div", {
      className: (0, _util.classes)('ui--Row', isInline && 'inline', className),
      style: style
    }, _react.default.createElement("div", {
      className: "ui--Row-base"
    }, this.renderIcon(), _react.default.createElement("div", {
      className: "ui--Row-details"
    }, this.renderName(), this.renderCodeHash(), this.renderTags()), this.renderButtons()), this.renderMessages(), this.renderChildren());
  }

  createState() {
    const {
      code: {
        json: {
          codeHash = DEFAULT_HASH,
          name = DEFAULT_NAME,
          tags = []
        }
      }
    } = this.props;
    return {
      address: DEFAULT_ADDR,
      codeHash,
      isEditingName: false,
      isEditingTags: false,
      name,
      tags
    };
  }

  renderCodeHash() {
    const {
      codeHash
    } = this.state;
    return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
      className: "ui--Row-name"
    }, name), _react.default.createElement("div", {
      className: "ui--Row-accountId"
    }, _react.default.createElement(_CopyButton.default, {
      isAddress: true,
      value: codeHash
    }, _react.default.createElement("span", null, (0, _util.toShortAddress)(codeHash)))));
  }

  renderButtons() {
    const {
      buttons
    } = this.props;

    if (!buttons) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Row-buttons"
    }, buttons);
  }

  renderIcon() {
    return _react.default.createElement(CodeIcon, null, _react.default.createElement(_Icon.default, {
      name: "code",
      size: "large"
    }));
  }

  renderMessages() {
    const {
      code: {
        contractAbi
      },
      withMessages
    } = this.props;

    if (!withMessages || !contractAbi) {
      return null;
    }

    return _react.default.createElement(_Messages.default, {
      contractAbi: contractAbi,
      isRemovable: true
    });
  }

}

var _default = (0, _hoc.withMulti)((0, _styledComponents.default)(CodeRow).withConfig({
  displayName: "CodeRow",
  componentId: "sc-187tvvu-1"
})(["", ""], _Row.styles), _translate.default);

exports.default = _default;