"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.collectionStyles = void 0;

var _react = _interopRequireDefault(require("react"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const collectionStyles = "\n  .ui--Collection-header {\n    display: flex;\n    margin-bottom: 0.5rem;\n    min-height: 2.75rem;\n\n    h1 {\n      flex: 1 1;\n      margin: 0;\n      text-transform: lowercase;\n    }\n  }\n\n  .ui--Collection-lowercase {\n    text-transform: lowercase;\n  }\n";
exports.collectionStyles = collectionStyles;

class Collection extends _react.default.PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      isEmpty: Collection.isEmpty(props.children)
    };
  }

  static isEmpty(children) {
    return !children || Array.isArray(children) && children.length === 0;
  }

  static getDerivedStateFromProps({
    isEmpty,
    children
  }) {
    return {
      isEmpty: isEmpty === undefined ? Collection.isEmpty(children) : isEmpty
    };
  }

  render() {
    const {
      banner,
      className
    } = this.props;
    const {
      isEmpty,
      showHeader
    } = this.state;
    return _react.default.createElement("div", {
      className: className
    }, showHeader && this.renderHeader(), banner, isEmpty ? this.renderEmpty() : this.renderCollection());
  }

  renderHeader() {
    const {
      buttons,
      headerText
    } = this.props;

    if (!headerText && !buttons) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Collection-header"
    }, _react.default.createElement("h1", null, headerText), buttons && _react.default.createElement("div", {
      className: "ui--Collection-buttons"
    }, buttons));
  }

  renderEmpty() {
    const {
      emptyText = this.props.t('No items'),
      showEmptyText = true
    } = this.props;

    if (!showEmptyText) {
      return null;
    }

    return _react.default.createElement("article", null, _react.default.createElement("div", {
      className: "ui--Collection-lowercase"
    }, emptyText));
  }

  renderCollection() {
    const {
      children
    } = this.props;
    return children;
  }

}

exports.default = Collection;