"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _codeflask = _interopRequireDefault(require("codeflask"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _util = require("@polkadot/react-components/util");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.

/**
 * @name Editor
 * @summary A code editor based on the codeflask npm module
 * @description It allows to live-edit code examples and JSON files.
 *
 * @example
 * <BR>
 *
 * ```javascript
 * import {Editor} from '@polkadot/react-components';
 *
 * <Editor
 *    className={string} // optional
 *    code={string}
 *    isValid={boolean}, // optional
 *    onEdit={() => callbackFunction}
 *  />
 * ```
 */
function Editor({
  className,
  code,
  isValid,
  onEdit
}) {
  const [editorId] = (0, _react.useState)("flask-".concat(Date.now()));
  const editorRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    const editor = new _codeflask.default("#".concat(editorId), {
      language: 'js',
      lineNumbers: true
    });
    editor.updateCode(code);
    editor.editorRoot.addEventListener('keydown', () => {
      editor.onUpdate(onEdit);
    });
    editorRef.current = editor;
  }, []);
  (0, _react.useEffect)(() => {
    editorRef.current && editorRef.current.updateCode(code);
  }, [code]);
  return _react.default.createElement("div", {
    className: (0, _util.classes)('ui-Editor', className, isValid === false ? 'invalid' : ''),
    id: editorId
  });
}

var _default = (0, _styledComponents.default)(Editor).withConfig({
  displayName: "Editor",
  componentId: "tyo6i8-0"
})([".codeflask{border:1px solid rgba(34,36,38,.15);background:transparent;}&.invalid{.codeflask{background-color:#fff6f6;border-color:#e0b4b4;}}"]);

exports.default = _default;