"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ExtrinsicDisplay;

var _react = _interopRequireWildcard(require("react"));

var _types = require("@polkadot/types");

var _reactComponents = require("@polkadot/react-components");

var _reactParams = _interopRequireDefault(require("@polkadot/react-params"));

var _util = require("@polkadot/util");

var _Params = _interopRequireDefault(require("./Params"));

// Copyright 2017-2020 @polkadot/app-extrinsics authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
function getParams({
  meta
}) {
  return _types.GenericCall.filterOrigin(meta).map(arg => ({
    name: arg.name.toString(),
    type: (0, _types.getTypeDef)(arg.type.toString())
  }));
}

function ExtrinsicDisplay({
  defaultValue,
  isDisabled,
  isError,
  isPrivate,
  label,
  onChange,
  onEnter,
  onEscape,
  withLabel
}) {
  const [extrinsic, setCall] = (0, _react.useState)({
    fn: defaultValue,
    params: getParams(defaultValue)
  });
  const [values, setValues] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    setValues([]);
  }, [extrinsic]);
  (0, _react.useEffect)(() => {
    const isValid = values.reduce((isValid, value) => isValid && !(0, _util.isUndefined)(value) && !(0, _util.isUndefined)(value.value) && value.isValid, extrinsic.params.length === values.length);
    let method;

    if (isValid) {
      try {
        method = extrinsic.fn(...values.map(({
          value
        }) => value));
      } catch (error) {// swallow
      }
    }

    onChange(method);
  }, [extrinsic, values]);

  const _onChangeMethod = fn => setCall({
    fn,
    params: getParams(fn)
  });

  const {
    fn: {
      meta,
      method,
      section
    },
    params
  } = extrinsic;
  return _react.default.createElement("div", {
    className: "extrinsics--Extrinsic"
  }, _react.default.createElement(_reactComponents.InputExtrinsic, {
    defaultValue: defaultValue,
    isDisabled: isDisabled,
    isError: isError,
    isPrivate: isPrivate,
    label: label,
    onChange: _onChangeMethod,
    withLabel: withLabel,
    help: meta === null || meta === void 0 ? void 0 : meta.documentation.join(' ')
  }), _react.default.createElement(_reactParams.default, {
    key: "".concat(section, ".").concat(method, ":params")
    /* force re-render on change */
    ,
    onChange: setValues,
    onEnter: onEnter,
    onEscape: onEscape,
    overrides: _Params.default,
    params: params
  }));
}