"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Forget;

var _react = _interopRequireDefault(require("react"));

var _reactComponents = require("@polkadot/react-components");

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/app-accounts authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
function getContent(mode, t) {
  switch (mode) {
    case 'account':
      return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("p", null, t('You are about to remove this account from your list of available accounts. Once completed, should you need to access it again, you will have to re-create the account either via seed or via a backup file.')), _react.default.createElement("p", null, t('This operation does not remove the history of the account from the chain, nor any associated funds from the account. The forget operation only limits your access to the account on this browser.')));

    case 'address':
      return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("p", null, t('You are about to remove this address from your address book. Once completed, should you need to access it again, you will have to re-add the address.')), _react.default.createElement("p", null, t('This operation does not remove the history of the account from the chain, nor any associated funds from the account. The forget operation only limits your access to the address on this browser.')));

    case 'contract':
      return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("p", null, t('You are about to remove this contract from your list of available contracts. Once completed, should you need to access it again, you will have to manually add the contract\'s address in the Instantiate tab.')), _react.default.createElement("p", null, t('This operation does not remove the history of the contract from the chain, nor any associated funds from its account. The forget operation only limits your access to the contract on this browser.')));

    case 'code':
      return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("p", null, t('You are about to remove this code from your list of available code hashes. Once completed, should you need to access it again, you will have to manually add the code hash again.')), _react.default.createElement("p", null, t('This operation does not remove the uploaded code WASM and ABI from the chain, nor any deployed contracts. The forget operation only limits your access to the code on this browser.')));
  }
}

function getHeaderText(mode, t) {
  switch (mode) {
    case 'account':
      return t('Confirm account removal');

    case 'address':
      return t('Confirm address removal');

    case 'contract':
      return t('Confirm contract removal');

    case 'code':
      return t('Confirm code removal');
  }
}

function renderContent(props, t) {
  const {
    address,
    code,
    mode = 'account'
  } = props;

  switch (mode) {
    case 'account':
    case 'address':
    case 'contract':
      return _react.default.createElement(_reactComponents.AddressRow, {
        isInline: true,
        value: address || ''
      }, getContent(mode, t));

    case 'code':
      return _react.default.createElement(_reactComponents.CodeRow, {
        isInline: true,
        code: code || ''
      }, getContent(mode, t));
  }
}

function Forget(props) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    mode = 'account',
    onForget,
    onClose
  } = props;
  return _react.default.createElement(_reactComponents.Modal, {
    className: "app--accounts-Modal",
    header: getHeaderText(mode, t),
    onClose: onClose
  }, _react.default.createElement(_reactComponents.Modal.Content, null, renderContent(props, t)), _react.default.createElement(_reactComponents.Modal.Actions, {
    onCancel: onClose
  }, _react.default.createElement(_reactComponents.Button, {
    isPrimary: true,
    onClick: onForget,
    label: t('Forget'),
    icon: "trash"
  })));
}