"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getIdentityTheme = getIdentityTheme;
exports.default = IdentityIcon;

var _react = _interopRequireWildcard(require("react"));

var _reactHooks = require("@polkadot/react-hooks");

var _reactIdenticon = _interopRequireDefault(require("@polkadot/react-identicon"));

var _uiSettings = _interopRequireDefault(require("@polkadot/ui-settings"));

var _reactQuery = require("@polkadot/react-query");

var _Context = _interopRequireDefault(require("./Status/Context"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// overrides based on the actual software node type
const NODES = {
  'edgeware-node': 'substrate',
  'joystream-node': 'beachball',
  'node-template': 'substrate',
  'parity-polkadot': 'polkadot',
  'polkadot-js': 'polkadot',
  'substrate-node': 'substrate'
};

function getIdentityTheme(systemName) {
  return _uiSettings.default.icon === 'default' && NODES[systemName] || _uiSettings.default.icon;
}

function IdentityIcon({
  className,
  onCopy,
  prefix,
  size,
  style,
  theme,
  value
}) {
  const {
    api,
    isApiReady,
    systemName
  } = (0, _reactHooks.useApi)();
  const {
    t
  } = (0, _translate.useTranslation)();
  const info = (0, _reactHooks.useCall)(isApiReady ? api.derive.accounts.info : undefined, [value]);
  const {
    queueAction
  } = (0, _react.useContext)(_Context.default);
  const validators = (0, _react.useContext)(_reactQuery.ValidatorsContext);
  const [isValidator, setIsValidator] = (0, _react.useState)(false);
  const [address, setAddress] = (0, _react.useState)(value === null || value === void 0 ? void 0 : value.toString());
  const thisTheme = theme || getIdentityTheme(systemName);
  (0, _react.useEffect)(() => {
    if (value) {
      setIsValidator(validators.includes(value.toString()));
    }
  }, [value, validators]);
  (0, _react.useEffect)(() => {
    if (info) {
      var _info$accountId;

      setAddress((_info$accountId = info.accountId) === null || _info$accountId === void 0 ? void 0 : _info$accountId.toString());
    }
  }, [info]);

  const _onCopy = account => {
    onCopy && onCopy(account);
    queueAction && queueAction({
      account,
      action: t('clipboard'),
      status: 'queued',
      message: t('address copied')
    });
  };

  return _react.default.createElement(_reactIdenticon.default, {
    className: className,
    isHighlight: isValidator,
    onCopy: _onCopy,
    prefix: prefix,
    size: size,
    style: style,
    theme: thisTheme,
    value: address
  });
}