"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Input;
exports.KEYS_PRE = exports.KEYS = exports.isSelectAll = exports.isPaste = exports.isCut = exports.isCopy = void 0;

var _react = _interopRequireWildcard(require("react"));

var _Input = _interopRequireDefault(require("semantic-ui-react/dist/commonjs/elements/Input/Input"));

var _util = require("@polkadot/util");

var _Labelled = _interopRequireDefault(require("./Labelled"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// Find decimal separator used in current locale
const getDecimalSeparator = () => 1.1.toLocaleString().replace(/\d/g, ''); // note: KeyboardEvent.keyCode and KeyboardEvent.which are deprecated


const KEYS = {
  A: 'a',
  ALT: 'Alt',
  ARROW_LEFT: 'ArrowLeft',
  ARROW_RIGHT: 'ArrowRight',
  BACKSPACE: 'Backspace',
  C: 'c',
  CMD: 'Meta',
  CTRL: 'Control',
  ENTER: 'Enter',
  ESCAPE: 'Escape',
  TAB: 'Tab',
  V: 'v',
  X: 'x',
  ZERO: '0',
  DECIMAL: getDecimalSeparator()
};
exports.KEYS = KEYS;
const KEYS_PRE = [KEYS.ALT, KEYS.CMD, KEYS.CTRL]; // reference: degrade key to keyCode for cross-browser compatibility https://www.w3schools.com/jsref/event_key_keycode.asp

exports.KEYS_PRE = KEYS_PRE;

const isCopy = (key, isPreKeyDown) => isPreKeyDown && key === KEYS.C;

exports.isCopy = isCopy;

const isCut = (key, isPreKeyDown) => isPreKeyDown && key === KEYS.X;

exports.isCut = isCut;

const isPaste = (key, isPreKeyDown) => isPreKeyDown && key === KEYS.V;

exports.isPaste = isPaste;

const isSelectAll = (key, isPreKeyDown) => isPreKeyDown && key === KEYS.A;

exports.isSelectAll = isSelectAll;
let counter = 0;

function Input({
  autoFocus = false,
  children,
  className,
  defaultValue,
  help,
  icon,
  isEditable = false,
  isAction = false,
  isDisabled = false,
  isDisabledError = false,
  isError = false,
  isFull = false,
  isHidden = false,
  isReadOnly = false,
  label,
  labelExtra,
  max,
  maxLength,
  min,
  name,
  onBlur,
  onChange,
  onEnter,
  onEscape,
  onKeyDown,
  onKeyUp,
  onPaste,
  placeholder,
  style,
  tabIndex,
  type = 'text',
  value,
  withEllipsis,
  withLabel
}) {
  const [stateName] = (0, _react.useState)("in_".concat(counter++, "_at_").concat(Date.now()));

  const _onBlur = () => {
    onBlur && onBlur();
  };

  const _onChange = ({
    target
  }) => {
    onChange && onChange(target.value);
  };

  const _onKeyDown = event => {
    onKeyDown && onKeyDown(event);
  };

  const _onKeyUp = event => {
    onKeyUp && onKeyUp(event);

    if (onEnter && event.keyCode === 13) {
      event.target.blur();
      onEnter();
    }

    if (onEscape && event.keyCode === 27) {
      event.target.blur();
      onEscape();
    }
  };

  const _onPaste = event => {
    onPaste && onPaste(event);
  };

  return _react.default.createElement(_Labelled.default, {
    className: className,
    help: help,
    isFull: isFull,
    label: label,
    labelExtra: labelExtra,
    style: style,
    withEllipsis: withEllipsis,
    withLabel: withLabel
  }, _react.default.createElement(_Input.default, {
    action: isAction,
    autoFocus: autoFocus,
    className: isEditable ? 'ui--Input edit icon' : 'ui--Input',
    defaultValue: (0, _util.isUndefined)(value) ? defaultValue || '' : undefined,
    disabled: isDisabled,
    error: !isDisabled && isError || isDisabledError,
    hidden: isHidden,
    id: name,
    iconPosition: (0, _util.isUndefined)(icon) ? undefined : 'left',
    max: max,
    maxLength: maxLength,
    min: min,
    name: name || stateName,
    onBlur: _onBlur,
    onChange: _onChange,
    onKeyDown: _onKeyDown,
    onKeyUp: _onKeyUp,
    placeholder: placeholder,
    readOnly: isReadOnly,
    tabIndex: tabIndex,
    type: type,
    value: value
  }, _react.default.createElement("input", {
    autoComplete: type === 'password' ? 'new-password' : 'off',
    autoCapitalize: "off",
    autoCorrect: "off",
    spellCheck: false,
    onPaste: _onPaste
  }), isEditable && _react.default.createElement("i", {
    className: "edit icon"
  }), icon, children));
}