"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _store = _interopRequireDefault(require("store"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _hoc = require("@polkadot/react-api/hoc");

var _uiKeyring = _interopRequireDefault(require("@polkadot/ui-keyring"));

var _options = _interopRequireDefault(require("@polkadot/ui-keyring/options"));

var _item = _interopRequireDefault(require("@polkadot/ui-keyring/options/item"));

var _util = require("@polkadot/util");

var _util2 = require("../util");

var _toAddress = _interopRequireDefault(require("../util/toAddress"));

var _Dropdown = _interopRequireDefault(require("../Dropdown"));

var _createHeader = _interopRequireDefault(require("./createHeader"));

var _createItem = _interopRequireDefault(require("./createItem"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const STORAGE_KEY = 'options:InputAddress';
const DEFAULT_TYPE = 'all';
const MULTI_DEFAULT = [];

function transformToAddress(value) {
  try {
    return (0, _toAddress.default)(value) || null;
  } catch (error) {
    console.error('Unable to transform address', value);
  }

  return null;
}

function transformToAccountId(value) {
  if (!value) {
    return null;
  }

  const accountId = transformToAddress(value);
  return !accountId ? null : accountId;
}

function createOption(address) {
  let isRecent;

  const pair = _uiKeyring.default.getAccount(address);

  let name;

  if (pair) {
    name = pair.meta.name;
  } else {
    const addr = _uiKeyring.default.getAddress(address);

    if (addr) {
      name = addr.meta.name;
      isRecent = addr.meta.isRecent;
    } else {
      isRecent = true;
    }
  }

  return (0, _createItem.default)((0, _item.default)(address, name), !isRecent);
}

function readOptions() {
  return _store.default.get(STORAGE_KEY) || {
    defaults: {}
  };
}

function getLastValue(type = DEFAULT_TYPE) {
  const options = readOptions();
  return options.defaults[type];
}

function setLastValue(type = DEFAULT_TYPE, value) {
  const options = readOptions();
  options.defaults[type] = value;

  _store.default.set(STORAGE_KEY, options);
}

class InputAddress extends _react.default.PureComponent {
  constructor(...args) {
    super(...args);
    this.state = {};

    this.renderLabel = ({
      value
    }) => {
      if (!value) {
        return undefined;
      }

      return (0, _util2.getAddressName)(value);
    };

    this.onChange = address => {
      const {
        onChange,
        type
      } = this.props;
      setLastValue(type, address);
      onChange && onChange(transformToAccountId(address));
    };

    this.onChangeMulti = addresses => {
      const {
        onChangeMulti
      } = this.props;

      if (onChangeMulti) {
        onChangeMulti(addresses.map(transformToAccountId).filter(address => address));
      }
    };

    this.onSearch = (filteredOptions, _query) => {
      const {
        isInput = true
      } = this.props;

      const query = _query.trim();

      const queryLower = query.toLowerCase();
      const matches = filteredOptions.filter(item => item.value !== null && (item.name.toLowerCase && item.name.toLowerCase().includes(queryLower) || item.value.toLowerCase().includes(queryLower)));
      const valueMatches = matches.filter(item => item.value !== null);

      if (isInput && valueMatches.length === 0) {
        const accountId = transformToAccountId(query);

        if (accountId) {
          matches.push(_uiKeyring.default.saveRecent(accountId.toString()).option);
        }
      }

      return matches.filter((item, index) => {
        const isLast = index === matches.length - 1;
        const nextItem = matches[index + 1];
        const hasNext = nextItem && nextItem.value;
        return item.value !== null || !isLast && !!hasNext;
      });
    };
  }

  static getDerivedStateFromProps({
    value
  }) {
    try {
      return {
        value: Array.isArray(value) ? value.map(_toAddress.default) : (0, _toAddress.default)(value) || undefined
      };
    } catch (error) {
      return null;
    }
  }

  render() {
    const {
      className,
      defaultValue,
      help,
      hideAddress = false,
      isDisabled = false,
      isError,
      isMultiple,
      label,
      labelExtra,
      options,
      optionsAll,
      placeholder,
      type = DEFAULT_TYPE,
      style,
      withEllipsis,
      withLabel
    } = this.props;
    const {
      value
    } = this.state;
    const hasOptions = options && options.length !== 0 || optionsAll && Object.keys(optionsAll[type]).length !== 0;

    if (!hasOptions && !isDisabled) {
      return null;
    }

    const lastValue = getLastValue(type);
    const lastOption = this.getLastOptionValue();
    const actualValue = transformToAddress(isDisabled || defaultValue && this.hasValue(defaultValue) ? defaultValue : this.hasValue(lastValue) ? lastValue : lastOption && lastOption.value);
    const actualOptions = options ? options.map(o => (0, _createItem.default)(o)) : isDisabled && actualValue ? [createOption(actualValue)] : this.getFiltered();

    const _defaultValue = isMultiple || !(0, _util.isUndefined)(value) ? undefined : actualValue;

    return _react.default.createElement(_Dropdown.default, {
      className: (0, _util2.classes)('ui--InputAddress', hideAddress && 'hideAddress', className),
      defaultValue: _defaultValue,
      help: help,
      isDisabled: isDisabled,
      isError: isError,
      isMultiple: isMultiple,
      label: label,
      labelExtra: labelExtra,
      onChange: isMultiple ? this.onChangeMulti : this.onChange,
      onSearch: this.onSearch,
      options: actualOptions,
      placeholder: placeholder,
      renderLabel: isMultiple ? this.renderLabel : undefined,
      style: style,
      value: isMultiple && !value ? MULTI_DEFAULT : value,
      withEllipsis: withEllipsis,
      withLabel: withLabel
    });
  }

  getLastOptionValue() {
    const available = this.getFiltered();
    return available.length ? available[available.length - 1] : undefined;
  }

  hasValue(test) {
    return this.getFiltered().some(({
      value
    }) => test === value);
  }

  getFiltered() {
    const {
      filter,
      optionsAll,
      type = DEFAULT_TYPE
    } = this.props;
    return !optionsAll ? [] : optionsAll[type].filter(({
      value
    }) => !!value && (!filter || filter.includes(value)));
  }

}

const ExportedComponent = (0, _hoc.withMulti)((0, _styledComponents.default)(InputAddress).withConfig({
  displayName: "InputAddress__ExportedComponent",
  componentId: "sc-1q8rsny-0"
})([".ui.dropdown .text{width:100%;}.ui.disabled.search{pointer-events:all;}.ui.search.selection.dropdown{> .text > .ui--KeyPair{.ui--IdentityIcon{border:1px solid #888;border-radius:50%;left:-2.75rem;top:-1.2rem;}.name{margin-left:0;}}}&.hideAddress .ui--KeyPair .address{flex:0;max-width:0;}"]), (0, _hoc.withObservable)(_options.default.optionsSubject, {
  propName: 'optionsAll',
  transform: optionsAll => Object.entries(optionsAll).reduce((result, [type, options]) => {
    result[type] = options.map(option => option.value === null ? (0, _createHeader.default)(option) : (0, _createItem.default)(option));
    return result;
  }, {})
}));
ExportedComponent.createOption = _createItem.default;
ExportedComponent.setLastValue = setLastValue;
var _default = ExportedComponent;
exports.default = _default;