"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _bn = _interopRequireDefault(require("bn.js"));

var _react = _interopRequireDefault(require("react"));

var _constants = require("@polkadot/react-components/constants");

var _Checks = require("@polkadot/react-signer/Checks");

var _reactComponents = require("@polkadot/react-components");

var _hoc = require("@polkadot/react-api/hoc");

var _constants2 = require("@polkadot/react-signer/Checks/constants");

var _util = require("@polkadot/util");

/* eslint-disable @typescript-eslint/camelcase */
// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const ZERO = new _bn.default(0);
const DEFAULT_BITLENGTH = _constants.BitLengthOption.CHAIN_SPEC;

class InputBalanceBonded extends _react.default.PureComponent {
  constructor(props) {
    super(props);
    this.state = void 0;

    this.setMaxBalance = () => {
      const {
        api,
        balances_fees = _constants2.ZERO_FEES,
        balances_all = _constants2.ZERO_BALANCE,
        controllerId,
        destination,
        extrinsicProp
      } = this.props;
      const {
        transactionBaseFee,
        transactionByteFee
      } = balances_fees;
      const {
        freeBalance
      } = balances_all;
      let prevMax = new _bn.default(0);
      let maxBalance = new _bn.default(1);
      let extrinsic;

      while (!prevMax.eq(maxBalance)) {
        prevMax = maxBalance;

        if (extrinsicProp === 'staking.bond') {
          extrinsic = controllerId && (destination || destination === 0) ? api.tx.staking.bond(controllerId, prevMax, destination) : null;
        } else if (extrinsicProp === 'staking.unbond') {
          extrinsic = api.tx.staking.unbond(prevMax);
        } else if (extrinsicProp === 'staking.bondExtra') {
          extrinsic = api.tx.staking.bondExtra(prevMax);
        }

        const txLength = (0, _Checks.calcTxLength)(extrinsic, balances_all.accountNonce);
        const fees = transactionBaseFee.add(transactionByteFee.mul(txLength));
        maxBalance = (0, _util.bnMax)(freeBalance.sub(fees), ZERO);
      }

      this.nextState({
        extrinsic,
        maxBalance
      });
    };

    this.state = {
      extrinsic: null,
      maxBalance: ZERO
    };
  }

  render() {
    const {
      autoFocus,
      className,
      defaultValue,
      help,
      isDisabled,
      isError,
      isFull,
      isZeroable,
      label,
      onChange,
      onEnter,
      onEscape,
      placeholder,
      style,
      value,
      withEllipsis,
      withLabel,
      withMax
    } = this.props;
    const {
      maxBalance
    } = this.state;
    return _react.default.createElement(_reactComponents.InputNumber, {
      autoFocus: autoFocus,
      className: className,
      bitLength: DEFAULT_BITLENGTH,
      defaultValue: defaultValue,
      help: help,
      isDisabled: isDisabled,
      isError: isError,
      isFull: isFull,
      isSi: true,
      isZeroable: isZeroable,
      label: label,
      maxValue: maxBalance,
      onChange: onChange,
      onEnter: onEnter,
      onEscape: onEscape,
      placeholder: placeholder,
      style: style,
      value: value,
      withEllipsis: withEllipsis,
      withLabel: withLabel,
      withMax: withMax
    });
  }

  componentDidUpdate(prevProps, prevState) {
    const {
      balances_all,
      balances_fees,
      controllerId,
      destination
    } = this.props;
    const {
      extrinsic
    } = this.state;
    const hasLengthChanged = (extrinsic && extrinsic.encodedLength || 0) !== (prevState.extrinsic && prevState.extrinsic.encodedLength || 0);

    if (controllerId && prevProps.controllerId !== controllerId || prevProps.destination !== destination || balances_fees !== prevProps.balances_fees || balances_all !== prevProps.balances_all || hasLengthChanged) {
      this.setMaxBalance();
    }
  }

  nextState(newState) {
    this.setState(prevState => {
      const {
        api,
        controllerId,
        destination,
        value
      } = this.props;
      const {
        maxBalance = prevState.maxBalance
      } = newState;
      const extrinsic = value && controllerId && destination ? api.tx.staking.bond(controllerId, value, destination) : null;
      return {
        extrinsic,
        maxBalance
      };
    });
  }

}

var _default = (0, _hoc.withMulti)(InputBalanceBonded, _hoc.withApi, (0, _hoc.withCalls)('derive.balances.fees', ['derive.balances.all', {
  paramName: 'stashId'
}]));

exports.default = _default;