"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDropzone = _interopRequireDefault(require("react-dropzone"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _util = require("@polkadot/util");

var _util2 = require("./util");

var _Labelled = _interopRequireDefault(require("./Labelled"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const BYTE_STR_0 = '0'.charCodeAt(0);
const BYTE_STR_X = 'x'.charCodeAt(0);

const NOOP = () => undefined;

function convertResult(result, convertHex) {
  const data = new Uint8Array(result); // this converts the input (if detected as hex), vai the hex conversion route

  if (convertHex && data[0] === BYTE_STR_0 && data[1] === BYTE_STR_X) {
    const hex = (0, _util.u8aToString)(data);

    if ((0, _util.isHex)(hex)) {
      return (0, _util.hexToU8a)(hex);
    }
  }

  return data;
}

function InputFile({
  accept,
  className,
  clearContent,
  convertHex,
  help,
  isDisabled,
  isError = false,
  label,
  onChange,
  placeholder,
  withEllipsis,
  withLabel
}) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const dropRef = (0, _react.createRef)();
  const [file, setFile] = (0, _react.useState)();

  const _onDrop = files => {
    files.forEach(file => {
      const reader = new FileReader();
      reader.onabort = NOOP;
      reader.onerror = NOOP;

      reader.onload = ({
        target
      }) => {
        if (target && target.result) {
          const name = file.name;
          const data = convertResult(target.result, convertHex);
          onChange && onChange(data, name);
          dropRef && setFile({
            name,
            size: data.length
          });
        }
      };

      reader.readAsArrayBuffer(file);
    });
  };

  const dropZone = _react.default.createElement(_reactDropzone.default, {
    accept: accept,
    disabled: isDisabled,
    multiple: false,
    ref: dropRef,
    onDrop: _onDrop
  }, ({
    getRootProps,
    getInputProps
  }) => _react.default.createElement("div", getRootProps({
    className: (0, _util2.classes)('ui--InputFile', isError ? 'error' : '', className)
  }), _react.default.createElement("input", getInputProps()), _react.default.createElement("em", {
    className: "label"
  }, !file || clearContent ? placeholder || t('click to select or drag and drop the file here') : placeholder || t('{{name}} ({{size}} bytes)', {
    replace: {
      name: file.name,
      size: (0, _util.formatNumber)(file.size)
    }
  }))));

  return label ? _react.default.createElement(_Labelled.default, {
    help: help,
    label: label,
    withEllipsis: withEllipsis,
    withLabel: withLabel
  }, dropZone) : dropZone;
}

var _default = (0, _styledComponents.default)(InputFile).withConfig({
  displayName: "InputFile",
  componentId: "vhlvx4-0"
})(["background:#fff;border:1px solid rgba(34,36,38,0.15);border-radius:0.28571429rem;font-size:1rem;margin:0.25rem 0;padding:1rem;width:100% !important;&.error{background:#fff6f6;border-color:#e0b4b4;}&:hover{background:#fefefe;cursor:pointer;}.label{color:rgba(0,0,0,.6);}"]);

exports.default = _default;