"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = InputNumber;
exports.TokenUnit = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _bn = _interopRequireDefault(require("bn.js"));

var _react = _interopRequireWildcard(require("react"));

var _util = require("@polkadot/util");

var _util2 = require("./util");

var _constants = require("./constants");

var _Dropdown = _interopRequireDefault(require("./Dropdown"));

var _Input = _interopRequireWildcard(require("./Input"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// import Button from './Button';
const DEFAULT_BITLENGTH = _constants.BitLengthOption.NORMAL_NUMBERS;
const ZERO = new _bn.default(0);
const TEN = new _bn.default(10);

class TokenUnit {
  static setAbbr(abbr = TokenUnit.abbr) {
    TokenUnit.abbr = abbr;
  }

}

exports.TokenUnit = TokenUnit;
TokenUnit.abbr = 'Unit';

function getGlobalMaxValue(bitLength) {
  return new _bn.default(2).pow(new _bn.default(bitLength || DEFAULT_BITLENGTH)).subn(1);
}

function getRegex(isDecimal) {
  return new RegExp(isDecimal ? "^(0|[1-9]\\d*)(\\".concat(_Input.KEYS.DECIMAL, "\\d*)?$") : '^(0|[1-9]\\d*)$');
}

function getSiOptions() {
  return _util.formatBalance.getOptions().map(({
    power,
    text,
    value
  }) => ({
    value,
    text: power === 0 ? TokenUnit.abbr : text
  }));
}

function getSiPowers(si) {
  if (!si) {
    return [ZERO, 0, 0];
  }

  const basePower = _util.formatBalance.getDefaults().decimals;

  return [new _bn.default(basePower + si.power), basePower, si.power];
}

function isValidNumber(bn, {
  bitLength = DEFAULT_BITLENGTH,
  isZeroable,
  maxValue
}) {
  if ( // cannot be negative
  bn.lt(ZERO) || // cannot be > than allowed max
  !bn.lt(getGlobalMaxValue(bitLength)) || // check if 0 and it should be a value
  !isZeroable && bn.eq(ZERO) || // check that the bitlengths fit
  bn.bitLength() > (bitLength || DEFAULT_BITLENGTH) || // cannot be > max (if specified)
  maxValue && maxValue.gtn(0) && bn.gt(maxValue)) {
    return false;
  }

  return true;
}

function inputToBn(input, si, props) {
  const [siPower, basePower, siUnitPower] = getSiPowers(si); // eslint-disable-next-line @typescript-eslint/prefer-regexp-exec

  const isDecimalValue = input.match(/^(\d+)\.(\d+)$/);
  let result;

  if (isDecimalValue) {
    if (siUnitPower - isDecimalValue[2].length < -basePower) {
      result = new _bn.default(-1);
    }

    const div = new _bn.default(input.replace(/\.\d*$/, ''));
    const modString = input.replace(/^\d+\./, '');
    const mod = new _bn.default(modString);
    result = div.mul(TEN.pow(siPower)).add(mod.mul(TEN.pow(new _bn.default(basePower + siUnitPower - modString.length))));
  } else {
    result = new _bn.default(input.replace(/[^\d]/g, '')).mul(TEN.pow(siPower));
  }

  return [result, isValidNumber(result, props)];
} // function bnToInput (bn: BN, si: SiDef | null): string {
//   const [siPower] = getSiPowers(si);
//
//   const base = TEN.pow(siPower);
//   const div = bn.div(base);
//   const mod = bn.mod(base);
//
//   return `${
//     div.gt(ZERO) ? div.toString() : '0'
//   }${
//     mod.gt(ZERO)
//       ? ((): string => {
//         const padding = Math.max(
//           mod.toString().length,
//           base.toString().length - div.toString().length,
//           bn.toString().length - div.toString().length
//         );
//
//         return `.${mod.toString(10, padding).replace(/0*$/, '')}`;
//       })()
//       : ''
//   }`;
// }


function getValuesFromString(value, si, props) {
  const [valueBn, isValid] = inputToBn(value, si, props);
  return [value, valueBn, isValid];
}

function getValuesFromBn(valueBn, si) {
  const value = si ? valueBn.div(TEN.pow(new _bn.default(si.power))).toString() : valueBn.toString();
  return [value, valueBn, true];
}

function getValues(value, si, props) {
  return _bn.default.isBN(value) ? getValuesFromBn(value, si) : getValuesFromString(value, si, props);
}

function isNewPropsValue(propsValue, value, valueBn) {
  return _bn.default.isBN(propsValue) ? !propsValue.eq(valueBn) : propsValue !== value;
}

function InputNumber(props) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    bitLength = DEFAULT_BITLENGTH,
    className,
    defaultValue = ZERO,
    help,
    isDecimal,
    isFull,
    isSi,
    isDisabled,
    isError = false,
    maxLength,
    maxValue,
    onChange,
    onEnter,
    onEscape,
    placeholder,
    style,
    value: propsValue
  } = props;
  const [si, setSi] = (0, _react.useState)(isSi ? _util.formatBalance.findSi('-') : null);
  const [isPreKeyDown, setIsPreKeyDown] = (0, _react.useState)(false);
  const [[value, valueBn, isValid], setValues] = (0, _react.useState)(getValues(propsValue || defaultValue, si, props));
  (0, _react.useEffect)(() => {
    if (propsValue && isNewPropsValue(propsValue, value, valueBn)) {
      setValues(getValues(propsValue, si, props));
    }
  }, [propsValue]);
  (0, _react.useEffect)(() => {
    setValues(getValues(value, si, props));
  }, [value, si, bitLength, maxValue]);
  (0, _react.useEffect)(() => {
    onChange && onChange(valueBn);
  }, [valueBn]);

  const _onChange = input => {
    setValues(getValuesFromString(input, si, props));
  };

  const _onKeyDown = event => {
    if (_Input.KEYS_PRE.includes(event.key)) {
      setIsPreKeyDown(true);
      return;
    }

    if (event.key.length === 1 && !isPreKeyDown) {
      const {
        selectionStart: i,
        selectionEnd: j,
        value
      } = event.target;
      const newValue = "".concat(value.substring(0, i || 0)).concat(event.key).concat(value.substring(j || 0));

      if (!getRegex(isDecimal || !!si).test(newValue)) {
        event.preventDefault();
      }
    }
  };

  const _onKeyUp = event => {
    if (_Input.KEYS_PRE.includes(event.key)) {
      setIsPreKeyDown(false);
    }
  };

  const _onPaste = event => {
    const {
      value: newValue
    } = event.target;

    if (!getRegex(isDecimal || !!si).test(newValue)) {
      event.preventDefault();
    }
  };

  const _onSelectSiUnit = siUnit => {
    setSi(_util.formatBalance.findSi(siUnit));
  }; // const _onClickMaxButton = (): void => {
  //   !!maxValue && setValue(bnToInput(maxValue, si));
  // };


  const maxValueLength = getGlobalMaxValue(bitLength).toString().length - 1;
  return _react.default.createElement(_Input.default, (0, _extends2.default)({}, props, {
    className: (0, _util2.classes)('ui--InputNumber', className),
    help: help,
    isAction: isSi,
    isDisabled: isDisabled,
    isError: !isValid || isError,
    isFull: isFull,
    maxLength: maxLength || maxValueLength,
    onChange: _onChange,
    onEnter: onEnter,
    onEscape: onEscape,
    onKeyDown: _onKeyDown,
    onKeyUp: _onKeyUp,
    onPaste: _onPaste,
    placeholder: placeholder || t('Positive number'),
    style: style,
    type: "text",
    value: value
  }), !!si && _react.default.createElement(_Dropdown.default, {
    dropdownClassName: "ui--SiDropdown",
    isButton: true,
    defaultValue: si.value,
    onChange: _onSelectSiUnit,
    options: getSiOptions()
  }));
}