"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = InputRpc;

var _react = _interopRequireWildcard(require("react"));

var _jsonrpc = _interopRequireDefault(require("@polkadot/jsonrpc"));

var _reactHooks = require("@polkadot/react-hooks");

var _LinkedWrapper = _interopRequireDefault(require("../InputExtrinsic/LinkedWrapper"));

var _SelectMethod = _interopRequireDefault(require("./SelectMethod"));

var _SelectSection = _interopRequireDefault(require("./SelectSection"));

var _method = _interopRequireDefault(require("./options/method"));

var _section = _interopRequireDefault(require("./options/section"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// TODO: We have a lot shared between this and InputExtrinsic & InputStorage
function InputRpc({
  className,
  defaultValue,
  help,
  label,
  onChange,
  style,
  withLabel
}) {
  const {
    api
  } = (0, _reactHooks.useApi)();
  const [optionsMethod, setOptionsMethod] = (0, _react.useState)((0, _method.default)(api, defaultValue.section));
  const [optionsSection] = (0, _react.useState)((0, _section.default)(api));
  const [value, setValue] = (0, _react.useState)(() => defaultValue);

  const _onMethodChange = newValue => {
    if (value.section === newValue.section && value.method === newValue.method) {
      return;
    } // set via callback since the method is a function itself


    setValue(() => newValue);
    onChange && onChange(newValue);
  };

  const _onSectionChange = section => {
    if (section === value.section) {
      return;
    }

    const optionsMethod = (0, _method.default)(api, section);
    setOptionsMethod(optionsMethod);

    _onMethodChange(_jsonrpc.default[section].methods[optionsMethod[0].value]);
  };

  return _react.default.createElement(_LinkedWrapper.default, {
    className: className,
    help: help,
    label: label,
    style: style,
    withLabel: withLabel
  }, _react.default.createElement(_SelectSection.default, {
    className: "small",
    onChange: _onSectionChange,
    options: optionsSection,
    value: value
  }), _react.default.createElement(_SelectMethod.default, {
    className: "large",
    onChange: _onMethodChange,
    options: optionsMethod,
    value: value
  }));
}