"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = InputStorage;

var _react = _interopRequireWildcard(require("react"));

var _reactHooks = require("@polkadot/react-hooks");

var _LinkedWrapper = _interopRequireDefault(require("../InputExtrinsic/LinkedWrapper"));

var _SelectKey = _interopRequireDefault(require("./SelectKey"));

var _SelectSection = _interopRequireDefault(require("./SelectSection"));

var _key = _interopRequireDefault(require("./options/key"));

var _section = _interopRequireDefault(require("./options/section"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// TODO: We have a lot shared between this and InputExtrinsic
function InputStorage({
  className,
  defaultValue,
  help,
  label,
  onChange,
  style,
  withLabel
}) {
  const {
    api
  } = (0, _reactHooks.useApi)();
  const [optionsMethod, setOptionsMethod] = (0, _react.useState)((0, _key.default)(api, defaultValue.creator.section));
  const [optionsSection] = (0, _react.useState)((0, _section.default)(api));
  const [value, setValue] = (0, _react.useState)(() => defaultValue);

  const _onKeyChange = newValue => {
    if (value.creator.section === newValue.creator.section && value.creator.method === newValue.creator.method) {
      return;
    } // set via callback


    setValue(() => newValue);
    onChange && onChange(newValue);
  };

  const _onSectionChange = section => {
    if (section === value.creator.section) {
      return;
    }

    const optionsMethod = (0, _key.default)(api, section);
    setOptionsMethod(optionsMethod);

    _onKeyChange(api.query[section][optionsMethod[0].value]);
  };

  return _react.default.createElement(_LinkedWrapper.default, {
    className: className,
    help: help,
    label: label,
    style: style,
    withLabel: withLabel
  }, _react.default.createElement(_SelectSection.default, {
    className: "small",
    onChange: _onSectionChange,
    options: optionsSection,
    value: value
  }), _react.default.createElement(_SelectKey.default, {
    className: "large",
    onChange: _onKeyChange,
    options: optionsMethod,
    value: value
  }));
}