"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = InputTags;

var _react = _interopRequireDefault(require("react"));

var _store = _interopRequireDefault(require("store"));

var _Dropdown = _interopRequireDefault(require("./Dropdown"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
function loadTags() {
  return (_store.default.get('tags') || ['Default']).sort();
}

function valueToOption(value) {
  return {
    key: value,
    text: value,
    value
  };
}

const tags = loadTags();
const options = tags.map(valueToOption);

function saveTags(tags) {
  _store.default.set('tags', tags.sort());
}

function onAddTag(value) {
  tags.push(value);
  options.push(valueToOption(value));
  saveTags(tags);
}

function InputTags({
  allowAdd = true,
  className,
  defaultValue,
  help,
  isDisabled,
  isError,
  label,
  onBlur,
  onChange,
  onClose,
  placeholder,
  searchInput,
  value,
  withLabel
}) {
  return _react.default.createElement(_Dropdown.default, {
    allowAdd: allowAdd && !isDisabled,
    className: className,
    defaultValue: defaultValue,
    help: help,
    isDisabled: isDisabled,
    isError: isError,
    isMultiple: true,
    label: label,
    onAdd: onAddTag,
    onBlur: onBlur,
    onChange: onChange,
    onClose: onClose,
    options: options,
    placeholder: placeholder,
    searchInput: searchInput,
    value: value,
    withLabel: withLabel
  });
}