"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = MessageSignature;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _types = require("@polkadot/types");

var _Icon = _interopRequireDefault(require("./Icon"));

var _Tooltip = _interopRequireDefault(require("./Tooltip"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const MAX_PARAM_LENGTH = 20;

const Signature = _styledComponents.default.div.withConfig({
  displayName: "MessageSignature__Signature",
  componentId: "k0azmn-0"
})(["font-family:monospace;font-weight:normal;flex-grow:1;.mutates{color:#ff8600;margin-left:0.5rem;opacity:0.6;}"]);

const Name = _styledComponents.default.span.withConfig({
  displayName: "MessageSignature__Name",
  componentId: "k0azmn-1"
})(["color:#2f8ddb;font-weight:bold;"]);

const Type = _styledComponents.default.span.withConfig({
  displayName: "MessageSignature__Type",
  componentId: "k0azmn-2"
})(["color:#21a2b2;"]);

const ReturnType = _styledComponents.default.span.withConfig({
  displayName: "MessageSignature__ReturnType",
  componentId: "k0azmn-3"
})(["color:#ff8600;"]);

function truncate(param) {
  return param.length > MAX_PARAM_LENGTH ? "".concat(param.substring(0, MAX_PARAM_LENGTH / 2), "\u2026").concat(param.substring(param.length - MAX_PARAM_LENGTH / 2)) : param;
}

function MessageSignature({
  message: {
    args,
    mutates,
    name,
    returnType
  },
  params = [],
  asConstructor = false,
  withTooltip = false
}) {
  const {
    t
  } = (0, _translate.useTranslation)();
  return _react.default.createElement(Signature, null, _react.default.createElement(Name, null, name), "(", args.map(({
    name,
    type
  }, index) => {
    return _react.default.createElement(_react.default.Fragment, {
      key: "".concat(name, "-args-").concat(index)
    }, name, ":", ' ', _react.default.createElement(Type, null, params && params[index] ? _react.default.createElement("b", null, truncate(params[index].toString())) : (0, _types.displayType)(type)), index < args.length - 1 && ', ');
  }), ")", !asConstructor && returnType && _react.default.createElement(_react.default.Fragment, null, ":", ' ', _react.default.createElement(ReturnType, null, (0, _types.displayType)(returnType))), mutates && _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_Icon.default, {
    "data-tip": true,
    "data-for": "mutates-".concat(name),
    name: "database",
    className: "mutates"
  }), withTooltip && _react.default.createElement(_Tooltip.default, {
    trigger: "mutates-".concat(name),
    text: t('Mutates contract state')
  })));
}