"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactComponents = require("@polkadot/react-components");

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _IconLink = _interopRequireDefault(require("./IconLink"));

var _MessageSignature = _interopRequireDefault(require("./MessageSignature"));

var _translate = require("./translate");

var _util = require("./util");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const NOOP = () => undefined;

function onSelect(props, messageIndex) {
  return function () {
    const {
      address: callAddress,
      contractAbi: {
        abi: {
          contract: {
            messages
          }
        }
      },
      onSelect
    } = props;

    if (!callAddress || !messages || !messages[messageIndex]) {
      return;
    }

    onSelect && onSelect(messageIndex)();
  };
}

function onSelectConstructor(props, index) {
  return function () {
    const {
      contractAbi: {
        abi: {
          contract: {
            constructors
          }
        }
      },
      onSelectConstructor
    } = props;

    if (!constructors || !constructors[index]) {
      return;
    }

    onSelectConstructor && onSelectConstructor(index);
  };
}

function renderItem(props, message, index, asConstructor = false) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    docs = [],
    name
  } = message;
  return _react.default.createElement("div", {
    key: name,
    className: (0, _util.classes)('message', !onSelect && 'exempt-hover', asConstructor && 'constructor')
  }, _react.default.createElement("div", {
    className: "info"
  }, _react.default.createElement(_MessageSignature.default, {
    asConstructor: asConstructor,
    message: message,
    withTooltip: true
  }), _react.default.createElement("details", {
    className: "docs"
  }, _react.default.createElement("summary", null, docs && docs.length > 0 ? docs.filter(line => line !== '').map((line, index) => _react.default.createElement(_react.default.Fragment, {
    key: "".concat(name, "-docs-").concat(index)
  }, _react.default.createElement("span", null, line), _react.default.createElement("br", null))) : _react.default.createElement("i", null, t('No documentation provided'))))), !asConstructor && props.onSelect && _react.default.createElement("div", {
    className: "accessory"
  }, _react.default.createElement(_reactComponents.Button, {
    className: "execute",
    icon: "play",
    onClick: onSelect(props, index),
    tooltip: t('Call this message')
  })), asConstructor && props.onSelectConstructor && _react.default.createElement("div", {
    className: "accessory"
  }, _react.default.createElement(_reactComponents.Button, {
    className: "execute",
    icon: "cloud upload",
    onClick: onSelectConstructor(props, index),
    tooltip: t('Deploy with this constructor')
  })));
}

function renderConstructor(props, index) {
  const {
    contractAbi: {
      abi: {
        contract: {
          constructors
        }
      }
    }
  } = props;

  if (!constructors[index]) {
    return null;
  }

  return renderItem(props, constructors[index], index, true);
}

function renderMessage(props, index) {
  const {
    contractAbi: {
      abi: {
        contract: {
          messages
        }
      }
    }
  } = props;

  if (!messages[index]) {
    return null;
  }

  return renderItem(props, messages[index], index);
}

function Messages(props) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const {
    className,
    contractAbi: {
      abi: {
        contract: {
          constructors,
          messages
        }
      }
    },
    isLabelled,
    isRemovable,
    onRemove = NOOP,
    withConstructors
  } = props;
  return _react.default.createElement("div", {
    className: (0, _util.classes)(className, 'ui--Messages', isLabelled && 'labelled')
  }, withConstructors && constructors.map((_, index) => renderConstructor(props, index)), messages.map((_, index) => renderMessage(props, index)), isRemovable && _react.default.createElement(_IconLink.default, {
    label: t('Remove ABI'),
    icon: "remove",
    className: "remove-abi",
    onClick: onRemove
  }));
}

var _default = (0, _styledComponents.default)(Messages).withConfig({
  displayName: "Messages",
  componentId: "g41wmq-0"
})(["font-size:0.9rem;padding:0;margin:0;.remove-abi{float:right;&:hover,&:hover:not(i){text-decoration:underline;}}&.labelled{background:white;box-sizing:border-box;border:1px solid rgba(34,36,38,.15);border-radius:.28571429rem;padding:1rem 1rem 0.5rem;width:100%;}& .message{width:calc(100% - 1rem);background:#f8f8f8;display:inline-flex;margin-bottom:0.5rem;padding:0.5rem;border-radius:0.7rem;transition:all 0.2s;&.constructor{background:#e8f4ff;}&:hover{.accessory .execute{display:block;color:rgba(0,0,0,0.2);&:hover{color:#2e86ab;}}}.info{flex:1 1;.docs{font-size:0.8rem;font-weight:normal;}}.accessory{width:3rem;display:flex;align-items:center;justify-content:center;.execute{display:none;background:transparent;font-size:1.5rem;margin:0;padding:0;}}&.disabled{opacity:1 !important;background:#eee !important;color:#555 !important;}}"]);

exports.default = _default;