"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.styles = void 0;

var _semanticUiReact = require("semantic-ui-react");

var _react = _interopRequireDefault(require("react"));

var _Button = _interopRequireDefault(require("./Button"));

var _util = require("./util");

var _CopyButton = _interopRequireDefault(require("./CopyButton"));

var _Input = _interopRequireDefault(require("./Input"));

var _InputTags = _interopRequireDefault(require("./InputTags"));

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const styles = "\n  text-align: left;\n\n  &.isDisabled {\n    opacity: 0.6;\n\n    .ui--IdentityIcon  {\n      filter: grayscale(100%);\n    }\n  }\n\n  &.isInline {\n    display: flex;\n\n    .ui--Row-accountId {\n      white-space: nowrap;\n    }\n  }\n\n  &.isInvalid {\n    .ui--Row-accountId,\n    .ui--Row-icon {\n      filter: grayscale(100);\n      opacity: 0.5;\n    }\n  }\n\n  button.ui.icon.editButton {\n    padding: 0em .3em .3em .3em;\n    color: #2e86ab;\n    background: none;\n    /*trick to let the button in the flow but keep the content centered regardless*/\n    margin-left: -2em;\n    position: relative;\n    right: -2.3em;\n    z-index: 1;\n  }\n\n  .editSpan {\n    white-space: nowrap;\n\n    &:before {\n      content: '';\n    }\n  }\n\n  .ui--Row-accountId,\n  .ui--Row-accountIndex {\n    font-family: monospace;\n    font-size: 1.25em;\n    padding: 0;\n    margin-bottom: 0.25rem;\n  }\n\n  .ui--Row-balances {\n    display: flex;\n    .column {\n      display: block;\n\n      label,\n      .result {\n        display: inline-block;\n        vertical-align: middle;\n      }\n    }\n\n    > span {\n      text-align: left;\n    }\n  }\n\n  .ui--Row-base {\n    display: flex;\n  }\n\n  .ui--Row-buttons {\n    position: relative;\n    margin-right: -0.5rem;\n    margin-top: -0.5rem;\n    white-space: nowrap;\n    height: 0rem;\n    overflow: visible;\n\n    button.ui.button:last-child {\n      margin-right: 0;\n    }\n  }\n\n  .ui--Row-children {\n    display: block;\n    padding-left: 1rem;\n    padding-top: 1rem;\n  }\n\n  .ui--Row-details {\n    flex: 1;\n    margin-right: 1rem;\n    padding: 0.25rem 0 0;\n    width: 100%;\n    min-width: 0;\n\n    .account-label{\n      margin: -0.75rem 0 0 0\n    }\n\n    * {\n      vertical-align: middle;\n    }\n  }\n\n  .ui--Row-icon {\n    flex: 0;\n    margin-right: 1em;\n    position: relative;\n\n    .ui--Row-icon-info {\n      left: -0.5rem;\n      position: absolute;\n      top: -0.5rem;\n    }\n  }\n\n  .ui--Row-address-or-name {\n    display: flex;\n    box-sizing: border-box;\n    margin: 0;\n    padding: 0;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: normal;\n\n    .withName {\n      white-space: nowrap;\n      text-transform: uppercase;\n      overflow: hidden;\n      text-overflow: inherit;\n    }\n  }\n\n  .ui--Row-name-input {\n    input {\n      height: 1em;\n      text-transform: uppercase;\n      margin-top: -0.3em;\n    }\n\n  }\n\n  .ui--Row-tags {\n    &.editable {\n      display: flex;\n      flex-wrap: wrap;\n      justify-content: left;\n\n      .addTags {\n        border: 1px #00000052 solid;\n        border-radius: .5em;\n        border-style: dashed;\n        color: grey;\n        font-size: x-small;\n        padding: .1em 0.3em 0.1em 0.3em;\n        margin-top: .2em;\n      }\n\n      > div.label {\n        margin-top:.3em\n      }\n    }\n  }\n\n  .ui--Row-tags-input {\n    margin-bottom: -1.4em;\n  }\n";
exports.styles = styles;

// const DEFAULT_ADDR = '5'.padEnd(16, 'x');
// const ICON_SIZE = 48;
class Row extends _react.default.PureComponent {
  constructor(...args) {
    super(...args);
    this.state = {
      isEditingName: false,
      isEditingTags: false
    };

    this.onChangeName = name => {
      this.setState({
        name
      });
    };

    this.onChangeTags = tags => {
      this.setState({
        tags
      });
    };

    this.saveName = void 0;
    this.saveTags = void 0;

    this.toggleNameEditor = () => {
      this.setState(({
        isEditingName
      }) => ({
        isEditingName: !isEditingName
      }));
    };

    this.toggleTagsEditor = () => {
      this.setState(({
        isEditingTags
      }) => ({
        isEditingTags: !isEditingTags
      }));
    };
  }

  renderButtons() {
    const {
      buttons
    } = this.props;
    return buttons ? _react.default.createElement("div", {
      className: "ui--Row-buttons"
    }, buttons) : null;
  }

  renderChildren() {
    const {
      children
    } = this.props;
    const hasChildren = !children ? false : Array.isArray(children) ? children.filter(child => !!child).length !== 0 : true;

    if (!hasChildren) {
      return null;
    }

    return _react.default.createElement("div", {
      className: "ui--Row-children"
    }, children);
  }

  renderEditIcon() {
    return _react.default.createElement("span", {
      className: "editSpan"
    }, _react.default.createElement(_Button.default, {
      className: "icon-button",
      icon: "edit",
      size: "mini",
      isPrimary: true,
      key: "unlock"
    }));
  }

  renderName(withCopy = false) {
    const {
      defaultName,
      isEditable
    } = this.props;
    const {
      address,
      isEditingName,
      name
    } = this.state;
    const withName = name !== defaultName; // can't be both editable and copyable

    return isEditingName ? _react.default.createElement(_Input.default, {
      autoFocus: true,
      className: "ui--Row-name-input",
      defaultValue: name,
      onBlur: this.saveName,
      onChange: this.onChangeName,
      onEnter: this.saveName,
      withLabel: false
    }) : _react.default.createElement("div", {
      className: (0, _util.classes)('ui--Row-address-or-name', isEditable && 'editable'),
      onClick: isEditable ? this.toggleNameEditor : undefined
    }, withCopy && !isEditable ? _react.default.createElement(_CopyButton.default, {
      isAddress: true,
      value: address
    }, _react.default.createElement("span", {
      className: "".concat(withName ? 'withName' : 'withAddr')
    }, withName ? name : (0, _util.toShortAddress)(address))) : _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("span", {
      className: "withName"
    }, name), isEditable && this.renderEditIcon()));
  }

  renderTags() {
    const {
      isEditingTags,
      tags
    } = this.state;
    const {
      isEditable,
      withTags = false
    } = this.props;

    if (!withTags) {
      return null;
    }

    return isEditingTags ? _react.default.createElement(_InputTags.default, {
      className: "ui--Row-tags-input",
      onBlur: this.saveTags,
      onChange: this.onChangeTags,
      onClose: this.saveTags,
      openOnFocus: true,
      defaultValue: tags,
      searchInput: {
        autoFocus: true
      },
      value: tags,
      withLabel: false
    }) : _react.default.createElement("div", {
      className: (0, _util.classes)('ui--Row-tags', isEditable && 'editable'),
      onClick: isEditable ? this.toggleTagsEditor : undefined
    }, !tags.length ? isEditable ? _react.default.createElement("span", {
      className: "addTags"
    }, "add tags") : undefined : tags.map(tag => _react.default.createElement(_semanticUiReact.Label, {
      key: tag,
      size: "tiny",
      color: "grey"
    }, tag)), isEditable && this.renderEditIcon());
  }

}

exports.default = Row;
Row.defaultProps = {
  defaultName: '<unknown>'
};