"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Queue;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _reactApi = require("@polkadot/react-api");

var _jsonrpc = _interopRequireDefault(require("@polkadot/jsonrpc"));

var _types = require("@polkadot/types");

var _Context = require("./Context");

var _constants = require("./constants");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

let nextId = 0;
const REMOVE_TIMEOUT = 7500;
const SUBMIT_RPC = _jsonrpc.default.author.methods.submitAndWatchExtrinsic;

function Queue({
  children
}) {
  const [_stqueue, _setStQueue] = (0, _react.useState)([]);
  const [_txqueue, _setTxQueue] = (0, _react.useState)([]);
  const stRef = (0, _react.useRef)(_stqueue);
  const txRef = (0, _react.useRef)(_txqueue);

  const setStQueue = st => {
    stRef.current = st;

    _setStQueue(st);
  };

  const setTxQueue = tx => {
    txRef.current = tx;

    _setTxQueue(tx);
  };

  const addToTxQueue = value => {
    const id = ++nextId;

    const removeItem = () => setTxQueue([...txRef.current.map(item => item.id === id ? _objectSpread({}, item, {
      status: 'completed'
    }) : item)]);

    setTxQueue([...txRef.current, _objectSpread({}, value, {
      id,
      removeItem,
      rpc: value.rpc || SUBMIT_RPC,
      status: 'queued'
    })]);
  };

  const queueAction = status => {
    const _status = Array.isArray(status) ? status : [status];

    if (_status.length) {
      setStQueue([...stRef.current, ..._status.map(item => {
        const id = ++nextId;

        const removeItem = () => setStQueue([...stRef.current.filter(item => item.id !== id)]);

        setTimeout(removeItem, REMOVE_TIMEOUT);
        return _objectSpread({}, item, {
          id,
          isCompleted: false,
          removeItem
        });
      })]);
    }
  };

  const queueExtrinsic = ({
    accountId,
    extrinsic,
    txFailedCb,
    txSuccessCb,
    txStartCb,
    txUpdateCb,
    isUnsigned
  }) => addToTxQueue({
    accountId,
    extrinsic,
    isUnsigned,
    txFailedCb,
    txSuccessCb,
    txStartCb,
    txUpdateCb
  });

  const queuePayload = (payload, signerCb) => addToTxQueue({
    accountId: payload.address,
    // this is not great, but the Extrinsic we don't need a submittable
    extrinsic: (0, _types.createType)(_reactApi.registry, 'Extrinsic', {
      method: (0, _types.createType)(_reactApi.registry, 'Call', payload.method)
    }, {
      version: payload.version
    }),
    payload,
    signerCb
  });

  const queueRpc = ({
    accountId,
    rpc,
    values
  }) => addToTxQueue({
    accountId,
    rpc,
    values
  });

  const queueSetTxStatus = (id, status, result, error) => {
    setTxQueue([...txRef.current.map(item => item.id === id ? _objectSpread({}, item, {
      error: error === undefined ? item.error : error,
      result: result === undefined ? item.result : result,
      status: item.status === 'completed' ? item.status : status
    }) : item)]);
    queueAction((result && result.events || []). // filter events handled globally, or those we are not interested in, these are
    // handled by the global overview, so don't add them here
    filter(record => !!record.event && record.event.section !== 'democracy').map(({
      event: {
        data,
        method,
        section
      }
    }) => {
      if (section === 'system' && method === 'ExtrinsicFailed') {
        const [dispatchError] = data;
        let message = dispatchError.type;

        if (dispatchError.isModule) {
          try {
            const mod = dispatchError.asModule;

            const error = _reactApi.registry.findMetaError(new Uint8Array([mod.index.toNumber(), mod.error.toNumber()]));

            message = "".concat(error.section, ".").concat(error.name);
          } catch (error) {// swallow
          }
        }

        return {
          action: "".concat(section, ".").concat(method),
          status: 'error',
          message
        };
      }

      return {
        action: "".concat(section, ".").concat(method),
        status: 'event',
        message: 'extrinsic event'
      };
    }));

    if (_constants.STATUS_COMPLETE.includes(status)) {
      setTimeout(() => {
        const item = txRef.current.find(item => item.id === id);
        item && item.removeItem();
      }, REMOVE_TIMEOUT);
    }
  };

  return _react.default.createElement(_Context.QueueProvider, {
    value: {
      queueAction,
      queueExtrinsic,
      queuePayload,
      queueRpc,
      queueSetTxStatus,
      stqueue: _stqueue,
      txqueue: _txqueue
    }
  }, children);
}