"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "StatusContext", {
  enumerable: true,
  get: function get() {
    return _Context.default;
  }
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactApi = require("@polkadot/react-api");

var _AddressMini = _interopRequireDefault(require("../AddressMini"));

var _Button = _interopRequireDefault(require("../Button"));

var _Icon = _interopRequireDefault(require("../Icon"));

var _translate = require("../translate");

var _util = require("../util");

var _Context = _interopRequireDefault(require("./Context"));

var _constants = require("./constants");

// Copyright 2017-2020 @polkadot/react-components authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
function iconName(status) {
  switch (status) {
    case 'error':
      return 'ban';

    case 'event':
      return 'assistive listening devices';

    case 'received':
      return 'telegram plane';

    default:
      return 'check';
  }
}

function signerIconName(status) {
  switch (status) {
    case 'cancelled':
      return 'ban';

    case 'completed':
    case 'finalized':
    case 'sent':
      return 'check';

    case 'dropped':
    case 'invalid':
    case 'usurped':
      return 'arrow down';

    case 'error':
      return 'warning sign';

    case 'queued':
      return 'random';

    default:
      return 'spinner';
  }
}

function renderStatus({
  account,
  action,
  id,
  message,
  removeItem,
  status
}) {
  return _react.default.createElement("div", {
    className: (0, _util.classes)('item', status),
    key: id
  }, _react.default.createElement("div", {
    className: "wrapper"
  }, _react.default.createElement("div", {
    className: "container"
  }, _react.default.createElement(_Icon.default, {
    name: "close",
    onClick: removeItem
  }), _react.default.createElement("div", {
    className: "short"
  }, _react.default.createElement(_Icon.default, {
    name: iconName(status)
  })), _react.default.createElement("div", {
    className: "desc"
  }, _react.default.createElement("div", {
    className: "header"
  }, action), account && _react.default.createElement(_AddressMini.default, {
    value: account
  }), _react.default.createElement("div", {
    className: "status"
  }, message)))));
}

function renderItem({
  id,
  extrinsic,
  error,
  removeItem,
  rpc,
  status
}) {
  let {
    method,
    section
  } = rpc;

  if (extrinsic) {
    const found = _reactApi.registry.findMetaCall(extrinsic.callIndex);

    if (found.section !== 'unknown') {
      method = found.method;
      section = found.section;
    }
  }

  const icon = signerIconName(status);
  return _react.default.createElement("div", {
    className: (0, _util.classes)('item', status),
    key: id
  }, _react.default.createElement("div", {
    className: "wrapper"
  }, _react.default.createElement("div", {
    className: "container"
  }, _constants.STATUS_COMPLETE.includes(status) && _react.default.createElement(_Icon.default, {
    name: "close",
    onClick: removeItem
  }), _react.default.createElement("div", {
    className: "short"
  }, _react.default.createElement(_Icon.default, {
    loading: icon === 'spinner',
    name: icon
  })), _react.default.createElement("div", {
    className: "desc"
  }, _react.default.createElement("div", {
    className: "header"
  }, section, ".", method), _react.default.createElement("div", {
    className: "status"
  }, error ? error.message : status)))));
}

function Status({
  className,
  stqueue = [],
  txqueue = []
}) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const allst = stqueue.filter(({
    isCompleted
  }) => !isCompleted);
  const alltx = txqueue.filter(({
    status
  }) => !['completed', 'incomplete'].includes(status));
  const completedTx = alltx.filter(({
    status
  }) => _constants.STATUS_COMPLETE.includes(status));

  if (!allst.length && !alltx.length) {
    return null;
  }

  const _onDismiss = () => {
    allst.map(s => s.removeItem());
    completedTx.map(t => t.removeItem());
  };

  return _react.default.createElement("div", {
    className: "ui--Status ".concat(className)
  }, allst.length + completedTx.length > 1 && _react.default.createElement("div", {
    className: "dismiss"
  }, _react.default.createElement(_Button.default, {
    isFluid: true,
    isNegative: true,
    onClick: _onDismiss,
    label: t('Dismiss all notifications'),
    icon: "cancel"
  })), alltx.map(renderItem), allst.map(renderStatus));
}

var _default = (0, _styledComponents.default)(Status).withConfig({
  displayName: "Status",
  componentId: "pogibc-0"
})(["display:inline-block;position:fixed;right:0.25rem;top:0.25rem;width:23rem;z-index:1001;.dismiss{margin-bottom:0.25rem;}.item{display:block;> .wrapper > .container{align-items:center;background:#00688b;border-radius:$small-corner;color:white;display:flex;justify-content:space-between;margin-bottom:0.25rem;padding:0 0.5rem;opacity:0.95;vertical-align:middle;position:relative;.desc{flex:1;overflow:hidden;padding:0.5rem 1rem;.status{font-weight:700;}.ui--AddressMini{.ui--AddressMini-address{min-width:0;text-align:left;}}}.header{opacity:0.66;}.short{font-size:2.5rem;opacity:0.75;padding:0.5rem 0 0.5rem 0.5rem;i.icon{line-height:1;}}.padded{padding:0.25rem 0 0 0 !important;}i.close{position:absolute;top:0.25rem;right:0rem;cursor:pointer;}}&.cancelled > .wrapper > .container{background:#cd9b1d}&.event > .wrapper > .container{background:teal;}&.completed > .wrapper > .container,&.finalized > .wrapper > .container,&.sent > .wrapper > .container,&.success > .wrapper > .container{background:green;}&.dropped > .wrapper > .container,&.error > .wrapper > .container,&.invalid > .wrapper > .container,&.usurped > .wrapper > .container{background:red;}}"]);

exports.default = _default;