"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = TreasuryProposal;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireWildcard(require("react"));

var _reactComponents = require("@polkadot/react-components");

var _reactHooks = require("@polkadot/react-hooks");

var _reactQuery = require("@polkadot/react-query");

var _Inset = _interopRequireDefault(require("./Inset"));

var _translate = require("./translate");

// Copyright 2017-2020 @polkadot/app-democracy authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
function TreasuryProposal({
  className,
  asInset,
  insetProps,
  onClick,
  proposal,
  proposalId
}) {
  const {
    t
  } = (0, _translate.useTranslation)();
  const [stateProposal, setProposal] = (0, _react.useState)(null);
  const {
    api
  } = (0, _reactHooks.useApi)();
  (0, _react.useEffect)(() => {
    if (!proposal && proposalId) {
      api.query.treasury.proposals(proposalId).then(proposal => proposal.unwrapOr(null)).catch(() => null).then(setProposal);
    } else {
      setProposal(proposal || null);
    }
  }, [proposal, proposalId]);

  if (!stateProposal) {
    return null;
  }

  const {
    bond,
    beneficiary,
    proposer,
    value
  } = stateProposal;

  const inner = _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_reactComponents.Labelled, {
    label: t('proposed by')
  }, _react.default.createElement(_reactComponents.InputAddress, {
    isDisabled: true,
    defaultValue: proposer,
    value: proposer,
    withLabel: false
  })), _react.default.createElement(_reactComponents.Labelled, {
    label: t('beneficiary')
  }, _react.default.createElement(_reactComponents.InputAddress, {
    isDisabled: true,
    defaultValue: beneficiary,
    value: beneficiary,
    withLabel: false
  })), _react.default.createElement(_reactComponents.Static, {
    label: t('value')
  }, _react.default.createElement(_reactQuery.FormatBalance, {
    value: value
  })), _react.default.createElement(_reactComponents.Static, {
    label: t('bond')
  }, _react.default.createElement(_reactQuery.FormatBalance, {
    value: bond
  })));

  if (asInset) {
    return _react.default.createElement(_Inset.default, (0, _extends2.default)({
      className: className
    }, insetProps), inner);
  }

  return _react.default.createElement("div", {
    className: className,
    onClick: onClick && onClick
  }, inner);
}