"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _hoc = require("@polkadot/react-api/hoc");

var _util = require("@polkadot/util");

var _Button = _interopRequireDefault(require("./Button"));

var _Context = require("./Status/Context");

// Copyright 2017-2020 @polkadot/app-123code authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
class TxButtonInner extends _react.default.PureComponent {
  constructor(...args) {
    super(...args);
    this.state = {
      isSending: false
    };

    this.send = () => {
      const {
        accountId,
        api,
        extrinsic: propsExtrinsic,
        isUnsigned,
        onClick,
        onFailed,
        onStart,
        onSuccess,
        onUpdate,
        params = [],
        queueExtrinsic,
        tx = '',
        withSpinner = true
      } = this.props;
      let extrinsic;

      if (propsExtrinsic) {
        extrinsic = propsExtrinsic;
      } else {
        const [section, method] = tx.split('.');
        (0, _util.assert)(api.tx[section] && api.tx[section][method], "Unable to find api.tx.".concat(section, ".").concat(method));
        extrinsic = api.tx[section][method](...((0, _util.isFunction)(params) ? params() : params));
      }

      (0, _util.assert)(extrinsic, 'Expected generated extrinsic passed to TxButton');

      if (withSpinner) {
        this.setState({
          isSending: true
        });
      }

      queueExtrinsic({
        accountId,
        extrinsic,
        isUnsigned,
        txFailedCb: withSpinner ? this.onFailed : onFailed,
        txStartCb: onStart,
        txSuccessCb: withSpinner ? this.onSuccess : onSuccess,
        txUpdateCb: onUpdate
      });
      onClick && onClick();
    };

    this.onFailed = result => {
      const {
        onFailed
      } = this.props;
      this.setState({
        isSending: false
      });
      onFailed && onFailed(result);
    };

    this.onSuccess = result => {
      const {
        onSuccess
      } = this.props;
      this.setState({
        isSending: false
      });
      onSuccess && onSuccess(result);
    };
  }

  render() {
    const {
      accountId,
      className,
      icon,
      iconSize,
      innerRef,
      isBasic,
      isDisabled,
      isNegative,
      isPrimary,
      isUnsigned,
      label,
      tooltip
    } = this.props;
    const {
      isSending
    } = this.state;
    const needsAccount = isUnsigned ? false : !accountId;
    return _react.default.createElement(_Button.default, {
      className: className,
      tooltip: tooltip,
      icon: icon,
      isBasic: isBasic,
      isDisabled: isSending || isDisabled || needsAccount,
      isLoading: isSending,
      isNegative: isNegative,
      isPrimary: (0, _util.isUndefined)(isPrimary) ? !isNegative && !isBasic : isPrimary,
      label: label,
      onClick: this.send,
      ref: innerRef,
      size: iconSize
    });
  }

}

class TxButton extends _react.default.PureComponent {
  constructor(...args) {
    super(...args);
    this.button = _react.default.createRef();

    this.send = () => {
      this.button.current.send();
    };
  }

  render() {
    const _this$props = this.props,
          {
      innerRef
    } = _this$props,
          props = (0, _objectWithoutProperties2.default)(_this$props, ["innerRef"]);
    return _react.default.createElement(_Context.QueueConsumer, null, ({
      queueExtrinsic,
      txqueue
    }) => _react.default.createElement(TxButtonInner, (0, _extends2.default)({}, props, {
      queueExtrinsic: queueExtrinsic,
      txqueue: txqueue,
      innerRef: innerRef
    })));
  }

}

var _default = (0, _hoc.withApi)(TxButton);

exports.default = _default;