"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _reactComponents = require("@polkadot/react-components");

// Copyright 2017-2020 @polkadot/app-contracts authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
class TxModal extends _reactComponents.TxComponent {
  constructor(...args) {
    super(...args);
    this.defaultState = {
      accountId: null,
      isOpen: false,
      isBusy: false
    };
    this.state = this.defaultState;

    this.headerText = () => '';

    this.accountHelp = () => this.props.t('Select the account to use for this action.');

    this.accountLabel = () => this.props.t('using my account');

    this.submitLabel = () => this.props.t('Submit');

    this.cancelLabel = () => this.props.t('Cancel');

    this.onChangeAccount = accountId => {
      this.setState({
        accountId
      });
    };

    this.onSubmit = () => {
      const {
        onSubmit
      } = this.props;
      this.toggleBusy(true);
      onSubmit && onSubmit();
    };

    this.onSuccess = () => {
      const {
        onClose,
        onSuccess
      } = this.props;
      onSuccess && onSuccess();
      onClose && onClose();
      this.hideModal();
    };

    this.onFailed = () => {
      const {
        onFailed
      } = this.props;
      this.toggleBusy(false);
      onFailed && onFailed();
    };

    this.isDisabled = () => {
      const {
        accountId
      } = this.state;
      return !accountId;
    };

    this.toggleBusy = isBusy => () => {
      this.setState({
        isBusy
      });
    };

    this.isUnsigned = () => false;

    this.txMethod = () => '';

    this.txParams = () => [];

    this.renderContent = () => null;

    this.renderPreContent = () => null;

    this.renderTrigger = () => null;

    this.renderButtons = () => {
      return this.renderTxButton();
    };

    this.reset = () => {
      this.setState(this.defaultState);
    };

    this.showModal = () => {
      this.setState({
        isOpen: true
      });
    };

    this.hideModal = () => {
      const {
        onClose
      } = this.props;
      onClose && onClose();
      this.setState(this.defaultState);
    };
  }

  render() {
    const {
      isOpen
    } = this.state;
    return _react.default.createElement(_react.default.Fragment, null, this.renderTrigger && this.renderTrigger(), _react.default.createElement(_reactComponents.Modal, {
      className: "ui--Modal",
      header: this.headerText(),
      onClose: this.hideModal,
      open: isOpen
    }, _react.default.createElement(_reactComponents.Modal.Content, null, this.renderPreContent(), this.renderInputAccount(), this.renderContent()), _react.default.createElement(_reactComponents.Modal.Actions, {
      onCancel: this.hideModal
    }, this.renderButtons())));
  }

  renderInputAccount() {
    const {
      filter
    } = this.props;
    const {
      accountId,
      isBusy
    } = this.state;
    return _react.default.createElement(_reactComponents.InputAddress, {
      defaultValue: accountId,
      filter: filter,
      help: this.accountHelp(),
      isDisabled: isBusy,
      isInput: false,
      label: this.accountLabel(),
      onChange: this.onChangeAccount,
      type: "account",
      value: accountId
    });
  }

  renderTxButton() {
    const {
      accountId
    } = this.state;
    return _react.default.createElement(_reactComponents.TxButton, (0, _extends2.default)({}, this.isUnsigned() ? {
      isUnsigned: true
    } : {
      accountId
    }, {
      isDisabled: this.isDisabled(),
      isPrimary: true,
      label: this.submitLabel(),
      icon: "sign-in",
      onClick: this.onSubmit,
      onFailed: this.onFailed,
      onSuccess: this.onSuccess,
      params: this.txParams(),
      ref: this.button,
      tx: this.txMethod()
    }));
  }

}

exports.default = TxModal;